Class: Imagekitio::Models::Accounts::UsageAnalyticsResponse::Device::ByBandwidth

Inherits:
RequestBandwidthEntry show all
Defined in:
lib/imagekitio/models/accounts/usage_analytics_response.rb,
sig/imagekitio/models/accounts/usage_analytics_response.rbs

Instance Attribute Summary collapse

Attributes inherited from RequestBandwidthEntry

#bandwidth_bytes, #request_count

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(by_bandwidth:, by_requests:) ⇒ ByBandwidth

CDN traffic grouped by device and operating system (e.g. Desktop - Apple Mac, Smartphone - Apple iPhone).

Parameters:



427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/imagekitio/models/accounts/usage_analytics_response.rb', line 427

class ByBandwidth < Imagekitio::Models::Accounts::RequestBandwidthEntry
  # @!attribute name
  #   Device category combined with operating system or vendor (e.g.
  #   `Desktop - Windows PC`).
  #
  #   @return [String]
  required :name, String

  # @!method initialize(name:)
  #   Some parameter documentations has been truncated, see
  #   {Imagekitio::Models::Accounts::UsageAnalyticsResponse::Device::ByBandwidth} for
  #   more details.
  #
  #   @param name [String] Device category combined with operating system or vendor (e.g. `Desktop - Window
end

Instance Attribute Details

#nameString

Device category combined with operating system or vendor (e.g. Desktop - Windows PC).

Parameters:

  • _ (String)

Returns:

  • (String)


433
# File 'lib/imagekitio/models/accounts/usage_analytics_response.rb', line 433

required :name, String

Instance Method Details

#to_hash{ name: String }

Returns:

  • ({ name: String })


282
# File 'sig/imagekitio/models/accounts/usage_analytics_response.rbs', line 282

def to_hash: -> { name: String }