Class: Imagekitio::Models::Accounts::UsageAnalyticsResponse::URLEndpoints::ByBandwidth

Inherits:
RequestBandwidthEntry show all
Defined in:
lib/imagekitio/models/accounts/usage_analytics_response.rb,
sig/imagekitio/models/accounts/usage_analytics_response.rbs

Instance Attribute Summary collapse

Attributes inherited from RequestBandwidthEntry

#bandwidth_bytes, #request_count

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(by_bandwidth:, by_requests:) ⇒ ByBandwidth

CDN traffic grouped by configured URL endpoint. Traffic that does not match any named URL endpoint pattern is grouped under Default.

Parameters:



982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'lib/imagekitio/models/accounts/usage_analytics_response.rb', line 982

class ByBandwidth < Imagekitio::Models::Accounts::RequestBandwidthEntry
  # @!attribute name
  #   URL endpoint name, or `Default` for traffic that does not match a named
  #   endpoint.
  #
  #   @return [String]
  required :name, String

  # @!method initialize(name:)
  #   Some parameter documentations has been truncated, see
  #   {Imagekitio::Models::Accounts::UsageAnalyticsResponse::URLEndpoints::ByBandwidth}
  #   for more details.
  #
  #   @param name [String] URL endpoint name, or `Default` for traffic that does not match a named endpoint
end

Instance Attribute Details

#nameString

URL endpoint name, or Default for traffic that does not match a named endpoint.

Parameters:

  • _ (String)

Returns:

  • (String)


988
# File 'lib/imagekitio/models/accounts/usage_analytics_response.rb', line 988

required :name, String

Instance Method Details

#to_hash{ name: String }

Returns:

  • ({ name: String })


744
# File 'sig/imagekitio/models/accounts/usage_analytics_response.rbs', line 744

def to_hash: -> { name: String }