Class: Imagekitio::Models::Accounts::UsageAnalyticsResponse::VideoProcessing
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::Accounts::UsageAnalyticsResponse::VideoProcessing
- Defined in:
- lib/imagekitio/models/accounts/usage_analytics_response.rb,
sig/imagekitio/models/accounts/usage_analytics_response.rbs
Instance Attribute Summary collapse
-
#codec ⇒ String
Video codec used for the output (e.g.
h264,av1). -
#duration_seconds ⇒ Float
Total output duration, in seconds, for this resolution and codec combination.
-
#resolution ⇒ String
Output resolution tier (e.g.
SD,HD,4K).
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(codec:, duration_seconds:, resolution:) ⇒ Object
|
|
# File 'lib/imagekitio/models/accounts/usage_analytics_response.rb', line 1034
|
Instance Attribute Details
#codec ⇒ String
Video codec used for the output (e.g. h264, av1).
1020 |
# File 'lib/imagekitio/models/accounts/usage_analytics_response.rb', line 1020 required :codec, String |
#duration_seconds ⇒ Float
Total output duration, in seconds, for this resolution and codec combination.
1026 |
# File 'lib/imagekitio/models/accounts/usage_analytics_response.rb', line 1026 required :duration_seconds, Float, api_name: :durationSeconds |
#resolution ⇒ String
Output resolution tier (e.g. SD, HD, 4K).
1032 |
# File 'lib/imagekitio/models/accounts/usage_analytics_response.rb', line 1032 required :resolution, String |
Instance Method Details
#to_hash ⇒ {
776 |
# File 'sig/imagekitio/models/accounts/usage_analytics_response.rbs', line 776
def to_hash: -> {
|