Class: Imagekitio::Models::AssetListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/imagekitio/models/asset_list_params.rb

Overview

Defined Under Namespace

Modules: FileType, Sort, Type

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(file_type: nil, limit: nil, path: nil, search_query: nil, skip: nil, sort: nil, type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::AssetListParams for more details.

Parameters:

  • (defaults to: nil)

    Filter results by file type.

  • (defaults to: nil)

    The maximum number of results to return in response.

  • (defaults to: nil)

    Folder path if you want to limit the search within a specific folder. For exampl

  • (defaults to: nil)

    Query string in a Lucene-like query language e.g. ‘createdAt > “7d”`.

  • (defaults to: nil)

    The number of results to skip before returning results.

  • (defaults to: nil)

    Sort the results by one of the supported fields in ascending or descending order

  • (defaults to: nil)

    Filter results by asset type.

  • (defaults to: {})


# File 'lib/imagekitio/models/asset_list_params.rb', line 79


Instance Attribute Details

#file_typeSymbol, ...

Filter results by file type.

  • all — include all file types

  • image — include only image files

  • non-image — include only non-image files (e.g., JS, CSS, video)

Returns:



18
# File 'lib/imagekitio/models/asset_list_params.rb', line 18

optional :file_type, enum: -> { Imagekitio::AssetListParams::FileType }

#limitInteger?

The maximum number of results to return in response.

Returns:



24
# File 'lib/imagekitio/models/asset_list_params.rb', line 24

optional :limit, Integer

#pathString?

Folder path if you want to limit the search within a specific folder. For example, /sales-banner/ will only search in folder sales-banner.

Note : If your use case involves searching within a folder as well as its subfolders, you can use path parameter in searchQuery with appropriate operator. Checkout [Supported parameters](/docs/api-reference/digital-asset-management-dam/list-and-search-assets#supported-parameters) for more information.

Returns:



37
# File 'lib/imagekitio/models/asset_list_params.rb', line 37

optional :path, String

#search_queryString?

Query string in a Lucene-like query language e.g. ‘createdAt > “7d”`.

Note : When the searchQuery parameter is present, the following query parameters will have no effect on the result:

  1. tags

  2. type

  3. name

[Learn more](/docs/api-reference/digital-asset-management-dam/list-and-search-assets#advanced-search-queries) from examples.

Returns:



53
# File 'lib/imagekitio/models/asset_list_params.rb', line 53

optional :search_query, String

#skipInteger?

The number of results to skip before returning results.

Returns:



59
# File 'lib/imagekitio/models/asset_list_params.rb', line 59

optional :skip, Integer

#sortSymbol, ...

Sort the results by one of the supported fields in ascending or descending order.

Returns:



66
# File 'lib/imagekitio/models/asset_list_params.rb', line 66

optional :sort, enum: -> { Imagekitio::AssetListParams::Sort }

#typeSymbol, ...

Filter results by asset type.

  • file — returns only files

  • file-version — returns specific file versions

  • folder — returns only folders

  • all — returns both files and folders (excludes file-version)

Returns:



77
# File 'lib/imagekitio/models/asset_list_params.rb', line 77

optional :type, enum: -> { Imagekitio::AssetListParams::Type }

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/imagekitio/models/asset_list_params.rb', line 111