Module: Imagekitio::Models::Beta::V2::FileUploadParams::ResponseField

Extended by:
Internal::Type::Enum
Defined in:
lib/imagekitio/models/beta/v2/file_upload_params.rb

Constant Summary collapse

TAGS =
:tags
CUSTOM_COORDINATES =
:customCoordinates
IS_PRIVATE_FILE =
:isPrivateFile
EMBEDDED_METADATA =
:embeddedMetadata
IS_PUBLISHED =
:isPublished
CUSTOM_METADATA =
:customMetadata
METADATA =
:metadata
SELECTED_FIELDS_SCHEMA =
:selectedFieldsSchema

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(file:, file_name:, token: nil, checks: nil, custom_coordinates: nil, custom_metadata: nil, description: nil, extensions: nil, folder: nil, is_private_file: nil, is_published: nil, overwrite_ai_tags: nil, overwrite_custom_metadata: nil, overwrite_file: nil, overwrite_tags: nil, response_fields: nil, tags: nil, transformation: nil, use_unique_file_name: nil, webhook_url: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::Beta::V2::FileUploadParams for more details.

Parameters:

  • The API accepts any of the following:

  • The name with which the file has to be uploaded.

  • (defaults to: nil)

    This is the client-generated JSON Web Token (JWT). The ImageKit.io server uses i

  • (defaults to: nil)

    Server-side checks to run on the asset.

  • (defaults to: nil)

    Define an important area in the image. This is only relevant for image type file

  • (defaults to: nil)

    JSON key-value pairs to associate with the asset. Create the custom metadata fie

  • (defaults to: nil)

    Optional text to describe the contents of the file.

  • (defaults to: nil)

    Array of extensions to be applied to the asset. Each extension can be configured

  • (defaults to: nil)

    The folder path in which the image has to be uploaded. If the folder(s) didn’t e

  • (defaults to: nil)

    Whether to mark the file as private or not.

  • (defaults to: nil)

    Whether to upload file as published or not.

  • (defaults to: nil)

    If set to true and a file already exists at the exact location, its AITags wil

  • (defaults to: nil)

    If the request does not have customMetadata, and a file already exists at the

  • (defaults to: nil)

    If false and useUniqueFileName is also false, and a file already exists at

  • (defaults to: nil)

    If the request does not have tags, and a file already exists at the exact loca

  • (defaults to: nil)

    Array of response field keys to include in the API response body.

  • (defaults to: nil)

    Set the tags while uploading the file.

  • (defaults to: nil)

    Configure pre-processing (pre) and post-processing (post) transformations.

  • (defaults to: nil)

    Whether to use a unique filename for this file or not.

  • (defaults to: nil)

    The final status of extensions after they have completed execution will be deliv

  • (defaults to: {})


317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/imagekitio/models/beta/v2/file_upload_params.rb', line 317

module ResponseField
  extend Imagekitio::Internal::Type::Enum

  TAGS = :tags
  CUSTOM_COORDINATES = :customCoordinates
  IS_PRIVATE_FILE = :isPrivateFile
   = :embeddedMetadata
  IS_PUBLISHED = :isPublished
   = :customMetadata
   = :metadata
  SELECTED_FIELDS_SCHEMA = :selectedFieldsSchema

  # @!method self.values
  #   @return [Array<Symbol>]
end