Class: Imagekitio::Models::Beta::V2::FileUploadResponse::SelectedFieldsSchema

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/imagekitio/models/beta/v2/file_upload_response.rb

Defined Under Namespace

Modules: DefaultValue, MaxValue, MinValue, SelectOption, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, default_value: nil, is_value_required: nil, max_length: nil, max_value: nil, min_length: nil, min_value: nil, read_only: nil, select_options: nil, select_options_truncated: nil) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::Beta::V2::FileUploadResponse::SelectedFieldsSchema for more details.

Parameters:

  • type (Symbol, Imagekitio::Models::Beta::V2::FileUploadResponse::SelectedFieldsSchema::Type)

    Type of the custom metadata field.

  • default_value (String, Float, Boolean, Array<String, Float, Boolean>) (defaults to: nil)

    The default value for this custom metadata field. The value should match the ‘ty

  • is_value_required (Boolean) (defaults to: nil)

    Specifies if the custom metadata field is required or not.

  • max_length (Float) (defaults to: nil)

    Maximum length of string. Only set if type is set to Text or Textarea.

  • max_value (String, Float) (defaults to: nil)

    Maximum value of the field. Only set if field type is Date or Number. For ‘D

  • min_length (Float) (defaults to: nil)

    Minimum length of string. Only set if type is set to Text or Textarea.

  • min_value (String, Float) (defaults to: nil)

    Minimum value of the field. Only set if field type is Date or Number. For ‘D

  • read_only (Boolean) (defaults to: nil)

    Indicates whether the custom metadata field is read only. A read only field cann

  • select_options (Array<String, Float, Boolean>) (defaults to: nil)

    An array of allowed values when field type is SingleSelect or MultiSelect.

  • select_options_truncated (Boolean) (defaults to: nil)

    Specifies if the selectOptions array is truncated. It is truncated when number o



# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 487

Instance Attribute Details

#default_valueString, ...

The default value for this custom metadata field. The value should match the type of custom metadata field.

Returns:

  • (String, Float, Boolean, Array<String, Float, Boolean>, nil)


420
421
422
# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 420

optional :default_value,
union: -> { Imagekitio::Models::Beta::V2::FileUploadResponse::SelectedFieldsSchema::DefaultValue },
api_name: :defaultValue

#is_value_requiredBoolean?

Specifies if the custom metadata field is required or not.

Returns:

  • (Boolean, nil)


428
# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 428

optional :is_value_required, Imagekitio::Internal::Type::Boolean, api_name: :isValueRequired

#max_lengthFloat?

Maximum length of string. Only set if type is set to Text or Textarea.

Returns:

  • (Float, nil)


434
# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 434

optional :max_length, Float, api_name: :maxLength

#max_valueString, ...

Maximum value of the field. Only set if field type is Date or Number. For Date type field, the value will be in ISO8601 string format. For Number type field, it will be a numeric value.

Returns:

  • (String, Float, nil)


442
443
444
# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 442

optional :max_value,
union: -> { Imagekitio::Models::Beta::V2::FileUploadResponse::SelectedFieldsSchema::MaxValue },
api_name: :maxValue

#min_lengthFloat?

Minimum length of string. Only set if type is set to Text or Textarea.

Returns:

  • (Float, nil)


450
# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 450

optional :min_length, Float, api_name: :minLength

#min_valueString, ...

Minimum value of the field. Only set if field type is Date or Number. For Date type field, the value will be in ISO8601 string format. For Number type field, it will be a numeric value.

Returns:

  • (String, Float, nil)


458
459
460
# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 458

optional :min_value,
union: -> { Imagekitio::Models::Beta::V2::FileUploadResponse::SelectedFieldsSchema::MinValue },
api_name: :minValue

#read_onlyBoolean?

Indicates whether the custom metadata field is read only. A read only field cannot be modified after being set. This field is configurable only via the **Path policy** feature.

Returns:

  • (Boolean, nil)


468
# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 468

optional :read_only, Imagekitio::Internal::Type::Boolean, api_name: :readOnly

#select_optionsArray<String, Float, Boolean>?

An array of allowed values when field type is SingleSelect or MultiSelect.

Returns:

  • (Array<String, Float, Boolean>, nil)


474
475
476
# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 474

optional :select_options,
-> { Imagekitio::Internal::Type::ArrayOf[union: Imagekitio::Models::Beta::V2::FileUploadResponse::SelectedFieldsSchema::SelectOption] },
api_name: :selectOptions

#select_options_truncatedBoolean?

Specifies if the selectOptions array is truncated. It is truncated when number of options are > 100.

Returns:

  • (Boolean, nil)


483
484
485
# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 483

optional :select_options_truncated,
Imagekitio::Internal::Type::Boolean,
api_name: :selectOptionsTruncated

#typeSymbol, Imagekitio::Models::Beta::V2::FileUploadResponse::SelectedFieldsSchema::Type

Type of the custom metadata field.



413
# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 413

required :type, enum: -> { Imagekitio::Models::Beta::V2::FileUploadResponse::SelectedFieldsSchema::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 526

.variantsArray(String, Float)

Returns:

  • (Array(String, Float))


# File 'lib/imagekitio/models/beta/v2/file_upload_response.rb', line 579