Class: Imagekitio::Models::CustomMetadataField

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/imagekitio/models/custom_metadata_field.rb

Overview

Defined Under Namespace

Classes: Schema

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, label:, name:, schema:) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::CustomMetadataField for more details.

Object containing details of a custom metadata field.

Parameters:

  • Unique identifier for the custom metadata field. Use this to update the field.

  • Human readable name of the custom metadata field. This name is displayed as form

  • API name of the custom metadata field. This becomes the key while setting ‘custo

  • An object that describes the rules for the custom metadata field value.



# File 'lib/imagekitio/models/custom_metadata_field.rb', line 34


Instance Attribute Details

#idString

Unique identifier for the custom metadata field. Use this to update the field.

Returns:



11
# File 'lib/imagekitio/models/custom_metadata_field.rb', line 11

required :id, String

#labelString

Human readable name of the custom metadata field. This name is displayed as form field label to the users while setting field value on the asset in the media library UI.

Returns:



19
# File 'lib/imagekitio/models/custom_metadata_field.rb', line 19

required :label, String

#nameString

API name of the custom metadata field. This becomes the key while setting customMetadata (key-value object) for an asset using upload or update API.

Returns:



26
# File 'lib/imagekitio/models/custom_metadata_field.rb', line 26

required :name, String

#schemaImagekitio::Models::CustomMetadataField::Schema

An object that describes the rules for the custom metadata field value.

Returns:



32
# File 'lib/imagekitio/models/custom_metadata_field.rb', line 32

required :schema, -> { Imagekitio::CustomMetadataField::Schema }