Class: Imagekitio::Models::CustomMetadataFieldCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::CustomMetadataFieldCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/imagekitio/models/custom_metadata_field_create_params.rb,
sig/imagekitio/models/custom_metadata_field_create_params.rbs
Overview
Defined Under Namespace
Classes: Schema
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Imagekitio
Instance Attribute Summary collapse
-
#description ⇒ String?
Optional description for the custom metadata field.
-
#label ⇒ String
Human readable name of the custom metadata field.
-
#name ⇒ String
API name of the custom metadata field.
- #schema ⇒ Imagekitio::Models::CustomMetadataFieldCreateParams::Schema
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
26 |
# File 'sig/imagekitio/models/custom_metadata_field_create_params.rbs', line 26
def initialize: (
|
Instance Attribute Details
#description ⇒ String?
Optional description for the custom metadata field. Can be up to 500 characters. This is shown as a hint to the users while setting the field's value on an asset in the media library UI.
37 |
# File 'lib/imagekitio/models/custom_metadata_field_create_params.rb', line 37 optional :description, String |
#label ⇒ String
Human readable name of the custom metadata field. This should be unique across all non deleted custom metadata fields. This name is displayed as form field label to the users while setting field value on an asset in the media library UI.
17 |
# File 'lib/imagekitio/models/custom_metadata_field_create_params.rb', line 17 required :label, String |
#name ⇒ String
API name of the custom metadata field. This should be unique across all (including deleted) custom metadata fields.
24 |
# File 'lib/imagekitio/models/custom_metadata_field_create_params.rb', line 24 required :name, String |
#schema ⇒ Imagekitio::Models::CustomMetadataFieldCreateParams::Schema
29 |
# File 'lib/imagekitio/models/custom_metadata_field_create_params.rb', line 29 required :schema, -> { Imagekitio::CustomMetadataFieldCreateParams::Schema } |
Instance Method Details
#to_hash ⇒ {
34 |
# File 'sig/imagekitio/models/custom_metadata_field_create_params.rbs', line 34
def to_hash: -> {
|