Module: Imagekitio::Models::CustomMetadataFieldCreateParams::Schema::MaxValue

Extended by:
Internal::Type::Union
Defined in:
lib/imagekitio/models/custom_metadata_field_create_params.rb

Overview

Maximum value of the field. Only set this property if field type is Date or Number. For Date type field, set the minimum date in ISO8601 string format. For Number type field, set the minimum numeric value.

See Also:

Method Summary

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info