Class: Imagekitio::Models::ExtensionConfig::AITasks::Task::SelectMetadata

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/imagekitio/models/extension_config.rb

Defined Under Namespace

Modules: Vocabulary

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Imagekitio::Internal::Type::BaseModel

Instance Attribute Details

#fieldString

Name of the custom metadata field to set. The field must exist in your account.

Returns:



216
# File 'lib/imagekitio/models/extension_config.rb', line 216

required :field, String

#instructionString

The question or instruction for the AI to analyze the image.

Returns:



222
# File 'lib/imagekitio/models/extension_config.rb', line 222

required :instruction, String

#max_selectionsInteger?

Maximum number of values to select from the vocabulary.

Returns:



235
# File 'lib/imagekitio/models/extension_config.rb', line 235

optional :max_selections, Integer

#min_selectionsInteger?

Minimum number of values to select from the vocabulary.

Returns:



241
# File 'lib/imagekitio/models/extension_config.rb', line 241

optional :min_selections, Integer

#typeSymbol, :select_metadata

Task type that analyzes the image and sets a custom metadata field value from a vocabulary.

Returns:



229
# File 'lib/imagekitio/models/extension_config.rb', line 229

required :type, const: :select_metadata

#vocabularyArray<String, Float, Boolean>?

Array of possible values matching the custom metadata field type.

Returns:



247
248
# File 'lib/imagekitio/models/extension_config.rb', line 247

optional :vocabulary,
-> { Imagekitio::Internal::Type::ArrayOf[union: Imagekitio::ExtensionConfig::AITasks::Task::::Vocabulary] }