Module: Imagekitio::Models::ExtensionConfig::AITasks::Task::SelectMetadata::Vocabulary

Extended by:
Internal::Type::Union
Defined in:
lib/imagekitio/models/extension_config.rb

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(field:, instruction:, max_selections: nil, min_selections: nil, vocabulary: nil, type: :select_metadata) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::ExtensionConfig::AITasks::Task::SelectMetadata for more details.

Parameters:

  • field (String)

    Name of the custom metadata field to set. The field must exist in your account.

  • instruction (String)

    The question or instruction for the AI to analyze the image.

  • max_selections (Integer) (defaults to: nil)

    Maximum number of values to select from the vocabulary.

  • min_selections (Integer) (defaults to: nil)

    Minimum number of values to select from the vocabulary.

  • vocabulary (Array<String, Float, Boolean>) (defaults to: nil)

    Array of possible values matching the custom metadata field type.

  • type (Symbol, :select_metadata) (defaults to: :select_metadata)

    Task type that analyzes the image and sets a custom metadata field value from a



267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/imagekitio/models/extension_config.rb', line 267

module Vocabulary
  extend Imagekitio::Internal::Type::Union

  variant String

  variant Float

  variant Imagekitio::Internal::Type::Boolean

  # @!method self.variants
  #   @return [Array(String, Float, Boolean)]
end