Class: Imagekitio::Models::ExtensionConfig::AutoTaggingExtension
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::ExtensionConfig::AutoTaggingExtension
- Defined in:
- lib/imagekitio/models/extension_config.rb
Defined Under Namespace
Modules: Name
Instance Attribute Summary collapse
-
#max_tags ⇒ Integer
Maximum number of tags to attach to the asset.
-
#min_confidence ⇒ Integer
Minimum confidence level for tags to be considered valid.
-
#name ⇒ Symbol, Imagekitio::Models::ExtensionConfig::AutoTaggingExtension::Name
Specifies the auto-tagging extension used.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(max_tags:, min_confidence:, name:) ⇒ Object
|
|
# File 'lib/imagekitio/models/extension_config.rb', line 101
|
Instance Attribute Details
#max_tags ⇒ Integer
Maximum number of tags to attach to the asset.
87 |
# File 'lib/imagekitio/models/extension_config.rb', line 87 required :max_tags, Integer, api_name: :maxTags |
#min_confidence ⇒ Integer
Minimum confidence level for tags to be considered valid.
93 |
# File 'lib/imagekitio/models/extension_config.rb', line 93 required :min_confidence, Integer, api_name: :minConfidence |
#name ⇒ Symbol, Imagekitio::Models::ExtensionConfig::AutoTaggingExtension::Name
Specifies the auto-tagging extension used.
99 |
# File 'lib/imagekitio/models/extension_config.rb', line 99 required :name, enum: -> { Imagekitio::ExtensionConfig::AutoTaggingExtension::Name } |