Class: Imagekitio::Models::ExtensionItem::AITasks::Task::SelectMetadata

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/imagekitio/models/extensions.rb

Defined Under Namespace

Modules: Vocabulary

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Imagekitio::Internal::Type::BaseModel

Instance Attribute Details

#fieldString

Name of the custom metadata field to set. The field must exist in your account.

Returns:



215
# File 'lib/imagekitio/models/extensions.rb', line 215

required :field, String

#instructionString

The question or instruction for the AI to analyze the image.

Returns:



221
# File 'lib/imagekitio/models/extensions.rb', line 221

required :instruction, String

#max_selectionsInteger?

Maximum number of values to select from the vocabulary.

Returns:



234
# File 'lib/imagekitio/models/extensions.rb', line 234

optional :max_selections, Integer

#min_selectionsInteger?

Minimum number of values to select from the vocabulary.

Returns:



240
# File 'lib/imagekitio/models/extensions.rb', line 240

optional :min_selections, Integer

#typeSymbol, :select_metadata

Task type that analyzes the image and sets a custom metadata field value from a vocabulary.

Returns:



228
# File 'lib/imagekitio/models/extensions.rb', line 228

required :type, const: :select_metadata

#vocabularyArray<String, Float, Boolean>?

Array of possible values matching the custom metadata field type.

Returns:



246
247
# File 'lib/imagekitio/models/extensions.rb', line 246

optional :vocabulary,
-> { Imagekitio::Internal::Type::ArrayOf[union: Imagekitio::ExtensionItem::AITasks::Task::::Vocabulary] }