Class: Imagekitio::Models::ExtensionItem::SavedExtension

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/imagekitio/models/extension_item.rb,
sig/imagekitio/models/extension_item.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, name: :"saved-extension") ⇒ SavedExtension

Returns a new instance of SavedExtension.

Parameters:

  • id (String)

    The unique ID of the saved extension to apply.

  • name (Symbol, :"saved-extension") (defaults to: :"saved-extension")

    Indicates this is a reference to a saved extension.

  • id: (String)
  • name: (:"saved-extension") (defaults to: :"saved-extension")


# File 'lib/imagekitio/models/extension_item.rb', line 686

Instance Attribute Details

#idString

The unique ID of the saved extension to apply.

Parameters:

  • value (String)

Returns:

  • (String)


678
# File 'lib/imagekitio/models/extension_item.rb', line 678

required :id, String

#nameSymbol, :"saved-extension"

Indicates this is a reference to a saved extension.

Parameters:

  • value (:"saved-extension")

Returns:

  • (Symbol, :"saved-extension")


684
# File 'lib/imagekitio/models/extension_item.rb', line 684

required :name, const: :"saved-extension"

Instance Method Details

#to_hash{ id: String, name: :"saved-extension" }

Returns:

  • ({ id: String, name: :"saved-extension" })


613
# File 'sig/imagekitio/models/extension_item.rbs', line 613

def to_hash: -> { id: String, name: :"saved-extension" }