Class: Imagekitio::Models::File

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/imagekitio/models/file.rb

Overview

Direct Known Subclasses

FileUpdateResponse

Defined Under Namespace

Modules: Type Classes: AITag, SelectedFieldsSchema, VersionInfo

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(confidence: nil, name: nil, source: nil) ⇒ Object

Some parameter documentations has been truncated, see AITag for more details.



# File 'lib/imagekitio/models/file.rb', line 281


Instance Attribute Details

#ai_tagsArray<Imagekitio::Models::File::AITag>?

An array of tags assigned to the file by auto tagging.



11
12
13
14
# File 'lib/imagekitio/models/file.rb', line 11

optional :ai_tags,
-> { Imagekitio::Internal::Type::ArrayOf[Imagekitio::File::AITag] },
api_name: :AITags,
nil?: true

#audio_codecString?

The audio codec used in the video (only for video/audio).



20
# File 'lib/imagekitio/models/file.rb', line 20

optional :audio_codec, String, api_name: :audioCodec

#bit_rateInteger?

The bit rate of the video in kbps (only for video).



26
# File 'lib/imagekitio/models/file.rb', line 26

optional :bit_rate, Integer, api_name: :bitRate

#created_atTime?

Date and time when the file was uploaded. The date and time is in ISO8601 format.



33
# File 'lib/imagekitio/models/file.rb', line 33

optional :created_at, Time, api_name: :createdAt

#custom_coordinatesString?

An string with custom coordinates of the file.



39
# File 'lib/imagekitio/models/file.rb', line 39

optional :custom_coordinates, String, api_name: :customCoordinates, nil?: true

#custom_metadataHash{Symbol=>Object}?

An object with custom metadata for the file.



45
46
47
# File 'lib/imagekitio/models/file.rb', line 45

optional :custom_metadata,
Imagekitio::Internal::Type::HashOf[Imagekitio::Internal::Type::Unknown],
api_name: :customMetadata

#descriptionString?

Optional text to describe the contents of the file. Can be set by the user or the ai-auto-description extension.



54
# File 'lib/imagekitio/models/file.rb', line 54

optional :description, String

#durationInteger?

The duration of the video in seconds (only for video).



60
# File 'lib/imagekitio/models/file.rb', line 60

optional :duration, Integer

#embedded_metadataHash{Symbol=>Object}?

Consolidated embedded metadata associated with the file. It includes exif, iptc, and xmp data.



67
68
69
# File 'lib/imagekitio/models/file.rb', line 67

optional :embedded_metadata,
Imagekitio::Internal::Type::HashOf[Imagekitio::Internal::Type::Unknown],
api_name: :embeddedMetadata

#file_idString?

Unique identifier of the asset.



75
# File 'lib/imagekitio/models/file.rb', line 75

optional :file_id, String, api_name: :fileId

#file_pathString?

Path of the file. This is the path you would use in the URL to access the file. For example, if the file is at the root of the media library, the path will be /file.jpg. If the file is inside a folder named images, the path will be /images/file.jpg.



84
# File 'lib/imagekitio/models/file.rb', line 84

optional :file_path, String, api_name: :filePath

#file_typeString?

Type of the file. Possible values are image, non-image.



90
# File 'lib/imagekitio/models/file.rb', line 90

optional :file_type, String, api_name: :fileType

#has_alphaBoolean?

Specifies if the image has an alpha channel.



96
# File 'lib/imagekitio/models/file.rb', line 96

optional :has_alpha, Imagekitio::Internal::Type::Boolean, api_name: :hasAlpha

#heightFloat?

Height of the file.



102
# File 'lib/imagekitio/models/file.rb', line 102

optional :height, Float

#is_private_fileBoolean?

Specifies if the file is private or not.



108
# File 'lib/imagekitio/models/file.rb', line 108

optional :is_private_file, Imagekitio::Internal::Type::Boolean, api_name: :isPrivateFile

#is_publishedBoolean?

Specifies if the file is published or not.



114
# File 'lib/imagekitio/models/file.rb', line 114

optional :is_published, Imagekitio::Internal::Type::Boolean, api_name: :isPublished

#mimeString?

MIME type of the file.



120
# File 'lib/imagekitio/models/file.rb', line 120

optional :mime, String

#nameString?

Name of the asset.



126
# File 'lib/imagekitio/models/file.rb', line 126

optional :name, String

#selected_fields_schemaHash{Symbol=>Imagekitio::Models::File::SelectedFieldsSchema}?

This field is included in the response only if the Path policy feature is available in the plan. It contains schema definitions for the custom metadata fields selected for the specified file path. Field selection can only be done when the Path policy feature is enabled.

Keys are the names of the custom metadata fields; the value object has details about the custom metadata schema.



138
139
140
# File 'lib/imagekitio/models/file.rb', line 138

optional :selected_fields_schema,
-> { Imagekitio::Internal::Type::HashOf[Imagekitio::File::SelectedFieldsSchema] },
api_name: :selectedFieldsSchema

#sizeFloat?

Size of the file in bytes.



146
# File 'lib/imagekitio/models/file.rb', line 146

optional :size, Float

#tagsArray<String>?

An array of tags assigned to the file. Tags are used to search files in the media library.



153
# File 'lib/imagekitio/models/file.rb', line 153

optional :tags, Imagekitio::Internal::Type::ArrayOf[String], nil?: true

#thumbnailString?

URL of the thumbnail image. This URL is used to access the thumbnail image of the file in the media library.



160
# File 'lib/imagekitio/models/file.rb', line 160

optional :thumbnail, String

#typeSymbol, ...

Type of the asset.



166
# File 'lib/imagekitio/models/file.rb', line 166

optional :type, enum: -> { Imagekitio::File::Type }

#updated_atTime?

Date and time when the file was last updated. The date and time is in ISO8601 format.



173
# File 'lib/imagekitio/models/file.rb', line 173

optional :updated_at, Time, api_name: :updatedAt

#urlString?

URL of the file.



179
# File 'lib/imagekitio/models/file.rb', line 179

optional :url, String

#version_infoImagekitio::Models::File::VersionInfo?

An object with details of the file version.



185
# File 'lib/imagekitio/models/file.rb', line 185

optional :version_info, -> { Imagekitio::File::VersionInfo }, api_name: :versionInfo

#video_codecString?

The video codec used in the video (only for video).



191
# File 'lib/imagekitio/models/file.rb', line 191

optional :video_codec, String, api_name: :videoCodec

#widthFloat?

Width of the file.



197
# File 'lib/imagekitio/models/file.rb', line 197

optional :width, Float

Class Method Details

.valuesArray<Symbol>



# File 'lib/imagekitio/models/file.rb', line 513


.variantsArray(String, Float, Boolean)



# File 'lib/imagekitio/models/file.rb', line 499