Class: Imagekitio::Models::File::AITag

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/imagekitio/models/file.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ai_tags: nil, audio_codec: nil, bit_rate: nil, created_at: nil, custom_coordinates: nil, custom_metadata: nil, description: nil, duration: nil, embedded_metadata: nil, file_id: nil, file_path: nil, file_type: nil, has_alpha: nil, height: nil, is_private_file: nil, is_published: nil, mime: nil, name: nil, selected_fields_schema: nil, size: nil, tags: nil, thumbnail: nil, type: nil, updated_at: nil, url: nil, version_info: nil, video_codec: nil, width: nil) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::File for more details.

Object containing details of a file or file version.

Parameters:

  • ai_tags (Array<Imagekitio::Models::File::AITag>, nil) (defaults to: nil)

    An array of tags assigned to the file by auto tagging.

  • audio_codec (String) (defaults to: nil)

    The audio codec used in the video (only for video/audio).

  • bit_rate (Integer) (defaults to: nil)

    The bit rate of the video in kbps (only for video).

  • created_at (Time) (defaults to: nil)

    Date and time when the file was uploaded. The date and time is in ISO8601 format

  • custom_coordinates (String, nil) (defaults to: nil)

    An string with custom coordinates of the file.

  • custom_metadata (Hash{Symbol=>Object}) (defaults to: nil)

    An object with custom metadata for the file.

  • description (String) (defaults to: nil)

    Optional text to describe the contents of the file. Can be set by the user or th

  • duration (Integer) (defaults to: nil)

    The duration of the video in seconds (only for video).

  • embedded_metadata (Hash{Symbol=>Object}) (defaults to: nil)

    Consolidated embedded metadata associated with the file. It includes exif, iptc,

  • file_id (String) (defaults to: nil)

    Unique identifier of the asset.

  • file_path (String) (defaults to: nil)

    Path of the file. This is the path you would use in the URL to access the file.

  • file_type (String) (defaults to: nil)

    Type of the file. Possible values are image, non-image.

  • has_alpha (Boolean) (defaults to: nil)

    Specifies if the image has an alpha channel.

  • height (Float) (defaults to: nil)

    Height of the file.

  • is_private_file (Boolean) (defaults to: nil)

    Specifies if the file is private or not.

  • is_published (Boolean) (defaults to: nil)

    Specifies if the file is published or not.

  • mime (String) (defaults to: nil)

    MIME type of the file.

  • name (String) (defaults to: nil)

    Name of the asset.

  • selected_fields_schema (Hash{Symbol=>Imagekitio::Models::File::SelectedFieldsSchema}) (defaults to: nil)

    This field is included in the response only if the Path policy feature is availa

  • size (Float) (defaults to: nil)

    Size of the file in bytes.

  • tags (Array<String>, nil) (defaults to: nil)

    An array of tags assigned to the file. Tags are used to search files in the medi

  • thumbnail (String) (defaults to: nil)

    URL of the thumbnail image. This URL is used to access the thumbnail image of th

  • type (Symbol, Imagekitio::Models::File::Type) (defaults to: nil)

    Type of the asset.

  • updated_at (Time) (defaults to: nil)

    Date and time when the file was last updated. The date and time is in ISO8601 fo

  • url (String) (defaults to: nil)

    URL of the file.

  • version_info (Imagekitio::Models::File::VersionInfo) (defaults to: nil)

    An object with details of the file version.

  • video_codec (String) (defaults to: nil)

    The video codec used in the video (only for video).

  • width (Float) (defaults to: nil)

    Width of the file.



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/imagekitio/models/file.rb', line 261

class AITag < Imagekitio::Internal::Type::BaseModel
  # @!attribute confidence
  #   Confidence score of the tag.
  #
  #   @return [Float, nil]
  optional :confidence, Float

  # @!attribute name
  #   Name of the tag.
  #
  #   @return [String, nil]
  optional :name, String

  # @!attribute source
  #   Source of the tag. Possible values are `google-auto-tagging` and
  #   `aws-auto-tagging`.
  #
  #   @return [String, nil]
  optional :source, String

  # @!method initialize(confidence: nil, name: nil, source: nil)
  #   Some parameter documentations has been truncated, see
  #   {Imagekitio::Models::File::AITag} for more details.
  #
  #   @param confidence [Float] Confidence score of the tag.
  #
  #   @param name [String] Name of the tag.
  #
  #   @param source [String] Source of the tag. Possible values are `google-auto-tagging` and `aws-auto-taggi
end

Instance Attribute Details

#confidenceFloat?

Confidence score of the tag.

Returns:

  • (Float, nil)


266
# File 'lib/imagekitio/models/file.rb', line 266

optional :confidence, Float

#nameString?

Name of the tag.

Returns:

  • (String, nil)


272
# File 'lib/imagekitio/models/file.rb', line 272

optional :name, String

#sourceString?

Source of the tag. Possible values are google-auto-tagging and aws-auto-tagging.

Returns:

  • (String, nil)


279
# File 'lib/imagekitio/models/file.rb', line 279

optional :source, String