Class: Imagekitio::Models::FileUploadParams::Transformation::Post::GifToVideo
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::FileUploadParams::Transformation::Post::GifToVideo
- Defined in:
- lib/imagekitio/models/file_upload_params.rb,
sig/imagekitio/models/file_upload_params.rbs
Instance Attribute Summary collapse
-
#type ⇒ Symbol, :"gif-to-video"
Converts an animated GIF into an MP4.
-
#value ⇒ String?
Optional transformation string to apply to the output video.
Instance Method Summary collapse
-
#initialize ⇒ GifToVideo
constructor
A new instance of GifToVideo.
- #to_hash ⇒ { type: :"gif-to-video", value: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ GifToVideo
Returns a new instance of GifToVideo.
265 |
# File 'sig/imagekitio/models/file_upload_params.rbs', line 265
def initialize: (?value: String, ?type: :"gif-to-video") -> void
|
Instance Attribute Details
#type ⇒ Symbol, :"gif-to-video"
Converts an animated GIF into an MP4.
447 |
# File 'lib/imagekitio/models/file_upload_params.rb', line 447 required :type, const: :"gif-to-video" |
#value ⇒ String?
Optional transformation string to apply to the output video.
Example: q-80
454 |
# File 'lib/imagekitio/models/file_upload_params.rb', line 454 optional :value, String |
Instance Method Details
#to_hash ⇒ { type: :"gif-to-video", value: String }
267 |
# File 'sig/imagekitio/models/file_upload_params.rbs', line 267
def to_hash: -> { type: :"gif-to-video", value: String }
|