Class: Imagekitio::Models::FileUploadResponse::SelectedFieldsSchema

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/imagekitio/models/file_upload_response.rb

Defined Under Namespace

Modules: DefaultValue, MaxValue, MinValue, SelectOption, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, default_value: nil, is_value_required: nil, max_length: nil, max_value: nil, min_length: nil, min_value: nil, read_only: nil, select_options: nil, select_options_truncated: nil) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::FileUploadResponse::SelectedFieldsSchema for more details.

Parameters:

  • Type of the custom metadata field.

  • (defaults to: nil)

    The default value for this custom metadata field. The value should match the ‘ty

  • (defaults to: nil)

    Specifies if the custom metadata field is required or not.

  • (defaults to: nil)

    Maximum length of string. Only set if type is set to Text or Textarea.

  • (defaults to: nil)

    Maximum value of the field. Only set if field type is Date or Number. For ‘D

  • (defaults to: nil)

    Minimum length of string. Only set if type is set to Text or Textarea.

  • (defaults to: nil)

    Minimum value of the field. Only set if field type is Date or Number. For ‘D

  • (defaults to: nil)

    Indicates whether the custom metadata field is read only. A read only field cann

  • (defaults to: nil)

    An array of allowed values when field type is SingleSelect or MultiSelect.

  • (defaults to: nil)

    Specifies if the selectOptions array is truncated. It is truncated when number o



# File 'lib/imagekitio/models/file_upload_response.rb', line 483


Instance Attribute Details

#default_valueString, ...

The default value for this custom metadata field. The value should match the type of custom metadata field.

Returns:



416
417
418
# File 'lib/imagekitio/models/file_upload_response.rb', line 416

optional :default_value,
union: -> { Imagekitio::Models::FileUploadResponse::SelectedFieldsSchema::DefaultValue },
api_name: :defaultValue

#is_value_requiredBoolean?

Specifies if the custom metadata field is required or not.

Returns:



424
# File 'lib/imagekitio/models/file_upload_response.rb', line 424

optional :is_value_required, Imagekitio::Internal::Type::Boolean, api_name: :isValueRequired

#max_lengthFloat?

Maximum length of string. Only set if type is set to Text or Textarea.

Returns:



430
# File 'lib/imagekitio/models/file_upload_response.rb', line 430

optional :max_length, Float, api_name: :maxLength

#max_valueString, ...

Maximum value of the field. Only set if field type is Date or Number. For Date type field, the value will be in ISO8601 string format. For Number type field, it will be a numeric value.

Returns:



438
439
440
# File 'lib/imagekitio/models/file_upload_response.rb', line 438

optional :max_value,
union: -> { Imagekitio::Models::FileUploadResponse::SelectedFieldsSchema::MaxValue },
api_name: :maxValue

#min_lengthFloat?

Minimum length of string. Only set if type is set to Text or Textarea.

Returns:



446
# File 'lib/imagekitio/models/file_upload_response.rb', line 446

optional :min_length, Float, api_name: :minLength

#min_valueString, ...

Minimum value of the field. Only set if field type is Date or Number. For Date type field, the value will be in ISO8601 string format. For Number type field, it will be a numeric value.

Returns:



454
455
456
# File 'lib/imagekitio/models/file_upload_response.rb', line 454

optional :min_value,
union: -> { Imagekitio::Models::FileUploadResponse::SelectedFieldsSchema::MinValue },
api_name: :minValue

#read_onlyBoolean?

Indicates whether the custom metadata field is read only. A read only field cannot be modified after being set. This field is configurable only via the **Path policy** feature.

Returns:



464
# File 'lib/imagekitio/models/file_upload_response.rb', line 464

optional :read_only, Imagekitio::Internal::Type::Boolean, api_name: :readOnly

#select_optionsArray<String, Float, Boolean>?

An array of allowed values when field type is SingleSelect or MultiSelect.

Returns:



470
471
472
# File 'lib/imagekitio/models/file_upload_response.rb', line 470

optional :select_options,
-> { Imagekitio::Internal::Type::ArrayOf[union: Imagekitio::Models::FileUploadResponse::SelectedFieldsSchema::SelectOption] },
api_name: :selectOptions

#select_options_truncatedBoolean?

Specifies if the selectOptions array is truncated. It is truncated when number of options are > 100.

Returns:



479
480
481
# File 'lib/imagekitio/models/file_upload_response.rb', line 479

optional :select_options_truncated,
Imagekitio::Internal::Type::Boolean,
api_name: :selectOptionsTruncated

#typeSymbol, Imagekitio::Models::FileUploadResponse::SelectedFieldsSchema::Type

Type of the custom metadata field.

Returns:



409
# File 'lib/imagekitio/models/file_upload_response.rb', line 409

required :type, enum: -> { Imagekitio::Models::FileUploadResponse::SelectedFieldsSchema::Type }

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/imagekitio/models/file_upload_response.rb', line 521


.variantsArray(String, Float)

Returns:



# File 'lib/imagekitio/models/file_upload_response.rb', line 574