Class: Imagekitio::Models::Folder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/imagekitio/models/folder.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at: nil, custom_metadata: nil, folder_id: nil, folder_path: nil, name: nil, type: nil, updated_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::Folder for more details.

Parameters:

  • (defaults to: nil)

    Date and time when the folder was created. The date and time is in ISO8601 forma

  • (defaults to: nil)

    An object with custom metadata for the folder. Returns empty object if no custom

  • (defaults to: nil)

    Unique identifier of the asset.

  • (defaults to: nil)

    Path of the folder. This is the path you would use in the URL to access the fold

  • (defaults to: nil)

    Name of the asset.

  • (defaults to: nil)

    Type of the asset.

  • (defaults to: nil)

    Date and time when the folder was last updated. The date and time is in ISO8601



# File 'lib/imagekitio/models/folder.rb', line 56


Instance Attribute Details

#created_atTime?

Date and time when the folder was created. The date and time is in ISO8601 format.

Returns:



11
# File 'lib/imagekitio/models/folder.rb', line 11

optional :created_at, Time, api_name: :createdAt

#custom_metadataHash{Symbol=>Object}?

An object with custom metadata for the folder. Returns empty object if no custom metadata is set.

Returns:



18
19
20
# File 'lib/imagekitio/models/folder.rb', line 18

optional :custom_metadata,
Imagekitio::Internal::Type::HashOf[Imagekitio::Internal::Type::Unknown],
api_name: :customMetadata

#folder_idString?

Unique identifier of the asset.

Returns:



26
# File 'lib/imagekitio/models/folder.rb', line 26

optional :folder_id, String, api_name: :folderId

#folder_pathString?

Path of the folder. This is the path you would use in the URL to access the folder. For example, if the folder is at the root of the media library, the path will be /folder. If the folder is inside another folder named images, the path will be /images/folder.

Returns:



35
# File 'lib/imagekitio/models/folder.rb', line 35

optional :folder_path, String, api_name: :folderPath

#nameString?

Name of the asset.

Returns:



41
# File 'lib/imagekitio/models/folder.rb', line 41

optional :name, String

#typeSymbol, ...

Type of the asset.

Returns:



47
# File 'lib/imagekitio/models/folder.rb', line 47

optional :type, enum: -> { Imagekitio::Folder::Type }

#updated_atTime?

Date and time when the folder was last updated. The date and time is in ISO8601 format.

Returns:



54
# File 'lib/imagekitio/models/folder.rb', line 54

optional :updated_at, Time, api_name: :updatedAt