Class: Imagekitio::Models::ImageOverlay

Inherits:
BaseOverlay show all
Defined in:
lib/imagekitio/models/image_overlay.rb

Defined Under Namespace

Modules: Encoding

Instance Attribute Summary collapse

Attributes inherited from BaseOverlay

#layer_mode, #position, #timing

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(input:, encoding: nil, transformation: nil, type: :image) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::ImageOverlay for more details.

Parameters:

  • input (String)

    Specifies the relative path to the image used as an overlay.

  • encoding (Symbol, Imagekitio::Models::ImageOverlay::Encoding) (defaults to: nil)

    The input path can be included in the layer as either ‘i-#input` or `ie-{base64

  • transformation (Array<Imagekitio::Models::Transformation>) (defaults to: nil)

    Array of transformations to be applied to the overlay image. Supported transform

  • type (Symbol, :image) (defaults to: :image)


# File 'lib/imagekitio/models/image_overlay.rb', line 43

Instance Attribute Details

#encodingSymbol, ...

The input path can be included in the layer as either ‘i-#input` or `ie-base64_encoded_input`. By default, the SDK determines the appropriate format automatically. To always use base64 encoding (`ie-base64`), set this parameter to base64. To always use plain text (`i-#input`), set it to plain.

Regardless of the encoding method:

  • Leading and trailing slashes are removed.

  • Remaining slashes within the path are replaced with ‘@@` when using plain text.



31
# File 'lib/imagekitio/models/image_overlay.rb', line 31

optional :encoding, enum: -> { Imagekitio::ImageOverlay::Encoding }

#inputString

Specifies the relative path to the image used as an overlay.

Returns:

  • (String)


10
# File 'lib/imagekitio/models/image_overlay.rb', line 10

required :input, String

#transformationArray<Imagekitio::Models::Transformation>?

Array of transformations to be applied to the overlay image. Supported transformations depends on the base/parent asset. See overlays on [Images](imagekit.io/docs/add-overlays-on-images#list-of-supported-image-transformations-in-image-layers) and [Videos](imagekit.io/docs/add-overlays-on-videos#list-of-transformations-supported-on-image-overlay).

Returns:



41
# File 'lib/imagekitio/models/image_overlay.rb', line 41

optional :transformation, -> { Imagekitio::Internal::Type::ArrayOf[Imagekitio::Transformation] }

#typeSymbol, :image

Returns:

  • (Symbol, :image)


15
# File 'lib/imagekitio/models/image_overlay.rb', line 15

required :type, const: :image