Class: Imagekitio::Models::NamedTransformation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/imagekitio/models/named_transformation.rb,
sig/imagekitio/models/named_transformation.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, enabled:, name:, transformation:) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::NamedTransformation for more details.

A named transformation is an alias for a transformation string, letting you apply and later update complex transformations without changing your image or video URLs. Learn more about named transformations.

Parameters:

  • id (String)

    Unique identifier for a named transformation.

  • created_at (Time)

    ISO 8601 timestamp of when the named transformation was created.

  • enabled (Boolean)

    Whether the named transformation is currently enabled. When set to false, requ

  • name (String)

    Alias for the transformation string, used in URLs as tr:n-<name>. This is case

  • transformation (String)

    The transformation string this named transformation refers to. Learn more about



# File 'lib/imagekitio/models/named_transformation.rb', line 40

Instance Attribute Details

#created_atTime

ISO 8601 timestamp of when the named transformation was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


16
# File 'lib/imagekitio/models/named_transformation.rb', line 16

required :created_at, Time, api_name: :createdAt

#enabledBoolean

Whether the named transformation is currently enabled. When set to false, requests using this named transformation fail at delivery time.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


23
# File 'lib/imagekitio/models/named_transformation.rb', line 23

required :enabled, Imagekitio::Internal::Type::Boolean

#idString

Unique identifier for a named transformation.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/imagekitio/models/named_transformation.rb', line 10

required :id, String

#nameString

Alias for the transformation string, used in URLs as tr:n-<name>. This is case-sensitive, contains only alphanumeric characters or _ (underscore), and is unique across all named transformations for your account.

Parameters:

  • value (String)

Returns:

  • (String)


31
# File 'lib/imagekitio/models/named_transformation.rb', line 31

required :name, String

#transformationString

The transformation string this named transformation refers to. Learn more about the transformation string syntax.

Parameters:

  • value (String)

Returns:

  • (String)


38
# File 'lib/imagekitio/models/named_transformation.rb', line 38

required :transformation, String

Instance Method Details

#to_hash{

Returns:

  • ({)


31
# File 'sig/imagekitio/models/named_transformation.rbs', line 31

def to_hash: -> {