Class: Imagekitio::Models::NamedTransformationCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::NamedTransformationCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/imagekitio/models/named_transformation_create_params.rb,
sig/imagekitio/models/named_transformation_create_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Imagekitio
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean?
Whether the named transformation is currently enabled.
-
#name ⇒ String
Alias for the transformation string, used in URLs as
tr:n-<name>. -
#transformation ⇒ String
The transformation string this named transformation refers to.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(name:, transformation:, enabled: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see NamedTransformationCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, transformation:, enabled: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Imagekitio::Models::NamedTransformationCreateParams for more details.
|
|
# File 'lib/imagekitio/models/named_transformation_create_params.rb', line 32
|
Instance Attribute Details
#enabled ⇒ Boolean?
Whether the named transformation is currently enabled. When set to false,
requests using this named transformation fail at delivery time.
30 |
# File 'lib/imagekitio/models/named_transformation_create_params.rb', line 30 optional :enabled, Imagekitio::Internal::Type::Boolean |
#name ⇒ String
Alias for the transformation string, used in URLs as tr:n-<name>. This is
case-sensitive, contains only alphanumeric characters or _ (underscore), and
is unique across all named transformations for your account.
16 |
# File 'lib/imagekitio/models/named_transformation_create_params.rb', line 16 required :name, String |
#transformation ⇒ String
The transformation string this named transformation refers to. Learn more about the transformation string syntax.
23 |
# File 'lib/imagekitio/models/named_transformation_create_params.rb', line 23 required :transformation, String |
Instance Method Details
#to_hash ⇒ {
26 |
# File 'sig/imagekitio/models/named_transformation_create_params.rbs', line 26
def to_hash: -> {
|