Class: Imagekitio::Models::OverlayPosition

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/imagekitio/models/overlay_position.rb

Defined Under Namespace

Modules: Focus, X, Y

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(focus: nil, x: nil, y_: nil) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::OverlayPosition for more details.

Parameters:

  • focus (Symbol, Imagekitio::Models::OverlayPosition::Focus) (defaults to: nil)

    Specifies the position of the overlay relative to the parent image or video.

  • x (Float, String) (defaults to: nil)

    Specifies the x-coordinate of the top-left corner of the base asset where the ov

  • y_ (Float, String) (defaults to: nil)

    Specifies the y-coordinate of the top-left corner of the base asset where the ov



# File 'lib/imagekitio/models/overlay_position.rb', line 33


Instance Attribute Details

#focusSymbol, ...

Specifies the position of the overlay relative to the parent image or video. Maps to lfo in the URL.



11
# File 'lib/imagekitio/models/overlay_position.rb', line 11

optional :focus, enum: -> { Imagekitio::OverlayPosition::Focus }

#xFloat, ...

Specifies the x-coordinate of the top-left corner of the base asset where the overlay’s top-left corner will be positioned. It also accepts arithmetic expressions such as bw_mul_0.4 or bw_sub_cw. Maps to lx in the URL. Learn about [Arithmetic expressions](imagekit.io/docs/arithmetic-expressions-in-transformations).

Returns:

  • (Float, String, nil)


21
# File 'lib/imagekitio/models/overlay_position.rb', line 21

optional :x, union: -> { Imagekitio::OverlayPosition::X }

#y_Float, ...

Specifies the y-coordinate of the top-left corner of the base asset where the overlay’s top-left corner will be positioned. It also accepts arithmetic expressions such as bh_mul_0.4 or bh_sub_ch. Maps to ly in the URL. Learn about [Arithmetic expressions](imagekit.io/docs/arithmetic-expressions-in-transformations).

Returns:

  • (Float, String, nil)


31
# File 'lib/imagekitio/models/overlay_position.rb', line 31

optional :y_, union: -> { Imagekitio::OverlayPosition::Y }, api_name: :y

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/imagekitio/models/overlay_position.rb', line 60


.variantsArray(Float, String)

Returns:

  • (Array(Float, String))


# File 'lib/imagekitio/models/overlay_position.rb', line 78