Module: Imagekitio::Models::OverlayPosition::AnchorPoint

Extended by:
Internal::Type::Enum
Defined in:
lib/imagekitio/models/overlay_position.rb,
sig/imagekitio/models/overlay_position.rbs

Overview

Sets the anchor point on the base asset from which the overlay offset is calculated. The default value is top_left. Maps to lap in the URL. Can only be used with one or more of x, y, xCenter, or yCenter.

See Also:

  • Imagekitio::Models::OverlayPosition#anchor_point

Constant Summary collapse

TOP =

Returns:

  • (:top)
:top
LEFT =

Returns:

  • (:left)
:left
RIGHT =

Returns:

  • (:right)
:right
BOTTOM =

Returns:

  • (:bottom)
:bottom
TOP_LEFT =

Returns:

  • (:top_left)
:top_left
TOP_RIGHT =

Returns:

  • (:top_right)
:top_right
BOTTOM_LEFT =

Returns:

  • (:bottom_left)
:bottom_left
BOTTOM_RIGHT =

Returns:

  • (:bottom_right)
:bottom_right
CENTER =

Returns:

  • (:center)
:center

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Imagekitio::Models::OverlayPosition::anchor_point]

Returns:

  • (::Array[Imagekitio::Models::OverlayPosition::anchor_point])


92
# File 'sig/imagekitio/models/overlay_position.rbs', line 92

def self?.values: -> ::Array[Imagekitio::Models::OverlayPosition::anchor_point]