Class: Imagekitio::Models::OverlayTiming

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/imagekitio/models/overlay_timing.rb

Defined Under Namespace

Modules: Duration, End, Start

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(duration: nil, end_: nil, start: nil) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::OverlayTiming for more details.

Parameters:

  • (defaults to: nil)

    Specifies the duration (in seconds) during which the overlay should appear on th

  • (defaults to: nil)

    Specifies the end time (in seconds) for when the overlay should disappear from t

  • (defaults to: nil)

    Specifies the start time (in seconds) for when the overlay should appear on the



# File 'lib/imagekitio/models/overlay_timing.rb', line 34


Instance Attribute Details

#durationFloat, ...

Specifies the duration (in seconds) during which the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g., 20 or 20.50) and arithmetic expressions such as bdu_mul_0.4 or bdu_sub_idu. Applies only if the base asset is a video. Maps to ldu in the URL.

Returns:



13
# File 'lib/imagekitio/models/overlay_timing.rb', line 13

optional :duration, union: -> { Imagekitio::OverlayTiming::Duration }

#end_Float, ...

Specifies the end time (in seconds) for when the overlay should disappear from the base video. If both end and duration are provided, duration is ignored. Accepts a positive number up to two decimal places (e.g., 20 or 20.50) and arithmetic expressions such as bdu_mul_0.4 or bdu_sub_idu. Applies only if the base asset is a video. Maps to leo in the URL.

Returns:



23
# File 'lib/imagekitio/models/overlay_timing.rb', line 23

optional :end_, union: -> { Imagekitio::OverlayTiming::End }, api_name: :end

#startFloat, ...

Specifies the start time (in seconds) for when the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g., 20 or 20.50) and arithmetic expressions such as bdu_mul_0.4 or bdu_sub_idu. Applies only if the base asset is a video. Maps to lso in the URL.

Returns:



32
# File 'lib/imagekitio/models/overlay_timing.rb', line 32

optional :start, union: -> { Imagekitio::OverlayTiming::Start }

Class Method Details

.variantsArray(Float, String)

Returns:



# File 'lib/imagekitio/models/overlay_timing.rb', line 57