Module: Imagekitio::Models::OverlayTiming::Duration
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/imagekitio/models/overlay_timing.rb,
sig/imagekitio/models/overlay_timing.rbs
Overview
Specifies the duration (in seconds) during which the overlay should appear on
the base video. Accepts a positive number up to two decimal places (e.g., 20
or 20.50) and arithmetic expressions such as bdu_mul_0.4 or bdu_sub_idu.
Applies only if the base asset is a video. Maps to ldu in the URL.
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.variants ⇒ ::Array[Imagekitio::Models::OverlayTiming::duration]
46 |
# File 'sig/imagekitio/models/overlay_timing.rbs', line 46
def self?.variants: -> ::Array[Imagekitio::Models::OverlayTiming::duration]
|