Module: Imagekitio::Models::OverlayTiming::Start
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/imagekitio/models/overlay_timing.rb
Overview
Specifies the start time (in seconds) for when the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g., 20 or 20.50) and arithmetic expressions such as bdu_mul_0.4 or bdu_sub_idu. Applies only if the base asset is a video. Maps to lso in the URL.
Class Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Float, String)
|
|
# File 'lib/imagekitio/models/overlay_timing.rb', line 92
|