Class: Imagekitio::Models::SolidColorOverlay

Inherits:
BaseOverlay show all
Defined in:
lib/imagekitio/models/solid_color_overlay.rb

Instance Attribute Summary collapse

Attributes inherited from BaseOverlay

#layer_mode, #position, #timing

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(color:, transformation: nil, type: :solidColor) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::SolidColorOverlay for more details.

Parameters:

  • Specifies the color of the block using an RGB hex code (e.g., FF0000), an RGBA

  • (defaults to: nil)

    Control width and height of the solid color overlay. Supported transformations d

  • (defaults to: :solidColor)


# File 'lib/imagekitio/models/solid_color_overlay.rb', line 31


Instance Attribute Details

#colorString

Specifies the color of the block using an RGB hex code (e.g., FF0000), an RGBA code (e.g., FFAABB50), or a color name (e.g., red). If an 8-character value is provided, the last two characters represent the opacity level (from 00 for 0.00 to 99 for 0.99).

Returns:



13
# File 'lib/imagekitio/models/solid_color_overlay.rb', line 13

required :color, String

#transformationArray<Imagekitio::Models::SolidColorOverlayTransformation>?

Control width and height of the solid color overlay. Supported transformations depend on the base/parent asset. See overlays on [Images](imagekit.io/docs/add-overlays-on-images#apply-transformation-on-solid-color-overlay) and [Videos](imagekit.io/docs/add-overlays-on-videos#apply-transformations-on-solid-color-block-overlay).

Returns:



28
29
# File 'lib/imagekitio/models/solid_color_overlay.rb', line 28

optional :transformation,
-> { Imagekitio::Internal::Type::ArrayOf[Imagekitio::SolidColorOverlayTransformation] }

#typeSymbol, :solidColor

Returns:



18
# File 'lib/imagekitio/models/solid_color_overlay.rb', line 18

required :type, const: :solidColor