Module: Imagekitio::Models::SolidColorOverlayTransformation::Gradient

Extended by:
Internal::Type::Union
Defined in:
lib/imagekitio/models/solid_color_overlay_transformation.rb,
sig/imagekitio/models/solid_color_overlay_transformation.rbs

Overview

Creates a linear gradient with two colors. Pass true for a default gradient, or provide a string for a custom gradient. Only works if the base asset is an image. See gradient.

See Also:

  • Imagekitio::Models::SolidColorOverlayTransformation#gradient

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.variants::Array[Imagekitio::Models::SolidColorOverlayTransformation::gradient]

Returns:

  • (::Array[Imagekitio::Models::SolidColorOverlayTransformation::gradient])


69
# File 'sig/imagekitio/models/solid_color_overlay_transformation.rbs', line 69

def self?.variants: -> ::Array[Imagekitio::Models::SolidColorOverlayTransformation::gradient]