Class: Imagekitio::Models::SubtitleOverlay

Inherits:
BaseOverlay show all
Defined in:
lib/imagekitio/models/subtitle_overlay.rb,
sig/imagekitio/models/subtitle_overlay.rbs

Defined Under Namespace

Modules: Encoding

Constant Summary

Constants inherited from BaseOverlay

BaseOverlay::Imagekitio

Instance Attribute Summary collapse

Attributes inherited from BaseOverlay

#layer_mode, #position, #timing

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(input:, encoding: nil, transformation: nil, type: :subtitle) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::SubtitleOverlay for more details.

Parameters:



# File 'lib/imagekitio/models/subtitle_overlay.rb', line 41

Instance Attribute Details

#encodingSymbol, ...

The input path can be included in the layer as either i-{input} or ie-{base64_encoded_input}. By default, the SDK determines the appropriate format automatically. To always use base64 encoding (ie-{base64}), set this parameter to base64. To always use plain text (i-{input}), set it to plain.

Regardless of the encoding method:

  • Leading and trailing slashes are removed.
  • Remaining slashes within the path are replaced with @@ when using plain text.


31
# File 'lib/imagekitio/models/subtitle_overlay.rb', line 31

optional :encoding, enum: -> { Imagekitio::SubtitleOverlay::Encoding }

#inputString

Specifies the relative path to the subtitle file used as an overlay.

Parameters:

  • _ (String)

Returns:

  • (String)


10
# File 'lib/imagekitio/models/subtitle_overlay.rb', line 10

required :input, String

#transformationArray<Imagekitio::Models::SubtitleOverlayTransformation>?

Control styling of the subtitle. See Styling subtitles.



38
39
# File 'lib/imagekitio/models/subtitle_overlay.rb', line 38

optional :transformation,
-> { Imagekitio::Internal::Type::ArrayOf[Imagekitio::SubtitleOverlayTransformation] }

#typeSymbol, :subtitle

Parameters:

  • _ (:subtitle)

Returns:

  • (Symbol, :subtitle)


15
# File 'lib/imagekitio/models/subtitle_overlay.rb', line 15

required :type, const: :subtitle

Instance Method Details

#`type`:subtitle

Returns:

  • (:subtitle)


16
# File 'sig/imagekitio/models/subtitle_overlay.rbs', line 16

def `type`: -> :subtitle

#to_hash{

Returns:

  • ({)


39
# File 'sig/imagekitio/models/subtitle_overlay.rbs', line 39

def to_hash: -> {