Module: Imagekitio::Models::SubtitleOverlay::Encoding
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/imagekitio/models/subtitle_overlay.rb
Overview
The input path can be included in the layer as either ‘i-#input` or `ie-base64_encoded_input`. By default, the SDK determines the appropriate format automatically. To always use base64 encoding (`ie-base64`), set this parameter to base64. To always use plain text (`i-#input`), set it to plain.
Regardless of the encoding method:
-
Leading and trailing slashes are removed.
-
Remaining slashes within the path are replaced with ‘@@` when using plain text.
Constant Summary collapse
- AUTO =
:auto- PLAIN =
:plain- BASE64 =
:base64
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/imagekitio/models/subtitle_overlay.rb', line 71
|