Module: Imagekitio::Models::TextOverlay::Encoding

Extended by:
Internal::Type::Enum
Defined in:
lib/imagekitio/models/text_overlay.rb,
sig/imagekitio/models/text_overlay.rbs

Overview

Text can be included in the layer as either i-{input} (plain text) or ie-{base64_encoded_input} (base64). By default, the SDK selects the appropriate format based on the input text. To always use base64 (ie-{base64}), set this parameter to base64. To always use plain text (i-{input}), set it to plain.

Regardless of the encoding method, the input text is always percent-encoded to ensure it is URL-safe.

Constant Summary collapse

AUTO =

Returns:

  • (:auto)
:auto
PLAIN =

Returns:

  • (:plain)
:plain
BASE64 =

Returns:

  • (:base64)
:base64

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/imagekitio/models/text_overlay.rb', line 66

Instance Method Details

#self?.values::Array[Imagekitio::Models::TextOverlay::encoding]

Returns:

  • (::Array[Imagekitio::Models::TextOverlay::encoding])


55
# File 'sig/imagekitio/models/text_overlay.rbs', line 55

def self?.values: -> ::Array[Imagekitio::Models::TextOverlay::encoding]