Module: Imagekitio::Models::Transformation::AIVariation

Extended by:
Internal::Type::Enum
Defined in:
lib/imagekitio/models/transformation.rb,
sig/imagekitio/models/transformation.rbs

Overview

Generates a variation of an image using AI. This produces a new image with slight variations from the original, such as changes in color, texture, and other visual elements, while preserving the structure and essence of the original image. Not supported inside overlay. See AI Generate Variations.

See Also:

  • Imagekitio::Models::Transformation#ai_variation

Constant Summary collapse

TRUE =

Returns:

  • (true)
true

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Imagekitio::Models::Transformation::ai_variation]

Returns:

  • (::Array[Imagekitio::Models::Transformation::ai_variation])


520
# File 'sig/imagekitio/models/transformation.rbs', line 520

def self?.values: -> ::Array[Imagekitio::Models::Transformation::ai_variation]