Class: Imagekitio::Models::UpdateFileRequest::UpdateFileDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::UpdateFileRequest::UpdateFileDetails
- Defined in:
- lib/imagekitio/models/update_file_request.rb,
sig/imagekitio/models/update_file_request.rbs
Defined Under Namespace
Modules: RemoveAITags
Instance Attribute Summary collapse
-
#custom_coordinates ⇒ String?
Define an important area in the image in the format
x,y,width,heighte.g. -
#custom_metadata ⇒ Hash{Symbol=>Object}?
A key-value data to be associated with the asset.
-
#description ⇒ String?
Optional text to describe the contents of the file.
-
#extensions ⇒ Array<Imagekitio::Models::ExtensionItem::RemoveBg, Imagekitio::Models::ExtensionItem::AIAutoDescription, Imagekitio::Models::ExtensionItem::AITasks, Imagekitio::Models::ExtensionItem::SavedExtension, Imagekitio::Models::ExtensionItem::AutoTaggingExtension>?
Array of extensions to be applied to the asset.
-
#remove_ai_tags ⇒ Array<String>, ...
An array of AITags associated with the file that you want to remove, e.g.
-
#tags ⇒ Array<String>?
An array of tags associated with the file, such as
["tag1", "tag2"]. -
#webhook_url ⇒ String?
The final status of extensions after they have completed execution will be delivered to this endpoint as a POST request.
Instance Method Summary collapse
-
#initialize(custom_coordinates: nil, custom_metadata: nil, description: nil, extensions: nil, remove_ai_tags: nil, tags: nil, webhook_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see UpdateFileDetails for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(custom_coordinates: nil, custom_metadata: nil, description: nil, extensions: nil, remove_ai_tags: nil, tags: nil, webhook_url: nil) ⇒ Object
Some parameter documentations has been truncated, see Imagekitio::Models::UpdateFileRequest::UpdateFileDetails for more details.
|
|
# File 'lib/imagekitio/models/update_file_request.rb', line 75
|
Instance Attribute Details
#custom_coordinates ⇒ String?
Define an important area in the image in the format x,y,width,height e.g.
10,10,100,100. Send null to unset this value.
19 |
# File 'lib/imagekitio/models/update_file_request.rb', line 19 optional :custom_coordinates, String, api_name: :customCoordinates, nil?: true |
#custom_metadata ⇒ Hash{Symbol=>Object}?
A key-value data to be associated with the asset. To unset a key, send null
value for that key. Before setting any custom metadata on an asset you have to
create the field using custom metadata fields API.
27 28 29 |
# File 'lib/imagekitio/models/update_file_request.rb', line 27 optional :custom_metadata, Imagekitio::Internal::Type::HashOf[Imagekitio::Internal::Type::Unknown], api_name: :customMetadata |
#description ⇒ String?
Optional text to describe the contents of the file.
35 |
# File 'lib/imagekitio/models/update_file_request.rb', line 35 optional :description, String |
#extensions ⇒ Array<Imagekitio::Models::ExtensionItem::RemoveBg, Imagekitio::Models::ExtensionItem::AIAutoDescription, Imagekitio::Models::ExtensionItem::AITasks, Imagekitio::Models::ExtensionItem::SavedExtension, Imagekitio::Models::ExtensionItem::AutoTaggingExtension>?
Array of extensions to be applied to the asset. Each extension can be configured with specific parameters based on the extension type.
42 |
# File 'lib/imagekitio/models/update_file_request.rb', line 42 optional :extensions, -> { Imagekitio::Internal::Type::ArrayOf[union: Imagekitio::ExtensionItem] } |
#remove_ai_tags ⇒ Array<String>, ...
An array of AITags associated with the file that you want to remove, e.g.
["car", "vehicle", "motorsports"].
If you want to remove all AITags associated with the file, send a string - "all".
Note: The remove operation for AITags executes before any of the extensions
are processed.
55 56 57 |
# File 'lib/imagekitio/models/update_file_request.rb', line 55 optional :remove_ai_tags, union: -> { Imagekitio::UpdateFileRequest::UpdateFileDetails::RemoveAITags }, api_name: :removeAITags |
#tags ⇒ Array<String>?
An array of tags associated with the file, such as ["tag1", "tag2"]. Send
null to unset all tags associated with the file.
64 |
# File 'lib/imagekitio/models/update_file_request.rb', line 64 optional :tags, Imagekitio::Internal::Type::ArrayOf[String], nil?: true |
#webhook_url ⇒ String?
The final status of extensions after they have completed execution will be delivered to this endpoint as a POST request. Learn more about the webhook payload structure.
73 |
# File 'lib/imagekitio/models/update_file_request.rb', line 73 optional :webhook_url, String, api_name: :webhookUrl |
Instance Method Details
#to_hash ⇒ {
60 |
# File 'sig/imagekitio/models/update_file_request.rbs', line 60
def to_hash: -> {
|