Class: Imagekitio::Models::VideoOverlay

Inherits:
BaseOverlay show all
Defined in:
lib/imagekitio/models/video_overlay.rb

Defined Under Namespace

Modules: Encoding

Instance Attribute Summary collapse

Attributes inherited from BaseOverlay

#layer_mode, #position, #timing

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(input:, encoding: nil, transformation: nil, type: :video) ⇒ Object

Some parameter documentations has been truncated, see Imagekitio::Models::VideoOverlay for more details.

Parameters:

  • Specifies the relative path to the video used as an overlay.

  • (defaults to: nil)

    The input path can be included in the layer as either ‘i-#input` or `ie-{base64

  • (defaults to: nil)

    Array of transformation to be applied to the overlay video. Except ‘streamingRes

  • (defaults to: :video)


# File 'lib/imagekitio/models/video_overlay.rb', line 41


Instance Attribute Details

#encodingSymbol, ...

The input path can be included in the layer as either ‘i-#input` or `ie-base64_encoded_input`. By default, the SDK determines the appropriate format automatically. To always use base64 encoding (`ie-base64`), set this parameter to base64. To always use plain text (`i-#input`), set it to plain.

Regardless of the encoding method:

  • Leading and trailing slashes are removed.

  • Remaining slashes within the path are replaced with ‘@@` when using plain text.

Returns:



31
# File 'lib/imagekitio/models/video_overlay.rb', line 31

optional :encoding, enum: -> { Imagekitio::VideoOverlay::Encoding }

#inputString

Specifies the relative path to the video used as an overlay.

Returns:



10
# File 'lib/imagekitio/models/video_overlay.rb', line 10

required :input, String

#transformationArray<Imagekitio::Models::Transformation>?

Array of transformation to be applied to the overlay video. Except streamingResolutions, all other video transformations are supported. See [Video transformations](imagekit.io/docs/video-transformation).

Returns:



39
# File 'lib/imagekitio/models/video_overlay.rb', line 39

optional :transformation, -> { Imagekitio::Internal::Type::ArrayOf[Imagekitio::Transformation] }

#typeSymbol, :video

Returns:



15
# File 'lib/imagekitio/models/video_overlay.rb', line 15

required :type, const: :video