Class: Imagekitio::Models::VideoTransformationErrorEvent::Data::Asset
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::VideoTransformationErrorEvent::Data::Asset
- Defined in:
- lib/imagekitio/models/video_transformation_error_event.rb,
sig/imagekitio/models/video_transformation_error_event.rbs
Overview
Instance Attribute Summary collapse
-
#url ⇒ String
URL to download or access the source video file.
Instance Method Summary collapse
-
#initialize ⇒ Asset
constructor
A new instance of Asset.
- #to_hash ⇒ { url: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Asset
Returns a new instance of Asset.
74 |
# File 'sig/imagekitio/models/video_transformation_error_event.rbs', line 74
def initialize: (url: String) -> void
|
Instance Attribute Details
#url ⇒ String
URL to download or access the source video file.
65 |
# File 'lib/imagekitio/models/video_transformation_error_event.rb', line 65 required :url, String |
Instance Method Details
#to_hash ⇒ { url: String }
76 |
# File 'sig/imagekitio/models/video_transformation_error_event.rbs', line 76
def to_hash: -> { url: String }
|