Class: Imagekitio::Models::Accounts::UsageAnalyticsResponse::Cache
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::Accounts::UsageAnalyticsResponse::Cache
- Defined in:
- lib/imagekitio/models/accounts/usage_analytics_response.rb,
sig/imagekitio/models/accounts/usage_analytics_response.rbs
Overview
Instance Attribute Summary collapse
-
#error_count ⇒ Float
Number of requests where the CDN encountered a cache error or exceeded capacity while serving the response.
-
#hit_count ⇒ Float
Number of requests served from cache, including full hits and revalidated hits.
-
#miss_count ⇒ Float
Number of requests that were not found in cache and had to be fetched from origin.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
185 |
# File 'sig/imagekitio/models/accounts/usage_analytics_response.rbs', line 185
def initialize: (
|
Instance Attribute Details
#error_count ⇒ Float
Number of requests where the CDN encountered a cache error or exceeded capacity while serving the response.
301 |
# File 'lib/imagekitio/models/accounts/usage_analytics_response.rb', line 301 required :error_count, Float, api_name: :errorCount |
#hit_count ⇒ Float
Number of requests served from cache, including full hits and revalidated hits.
307 |
# File 'lib/imagekitio/models/accounts/usage_analytics_response.rb', line 307 required :hit_count, Float, api_name: :hitCount |
#miss_count ⇒ Float
Number of requests that were not found in cache and had to be fetched from origin.
314 |
# File 'lib/imagekitio/models/accounts/usage_analytics_response.rb', line 314 required :miss_count, Float, api_name: :missCount |
Instance Method Details
#to_hash ⇒ {
191 |
# File 'sig/imagekitio/models/accounts/usage_analytics_response.rbs', line 191
def to_hash: -> {
|