Class: Imagekitio::Models::AssetListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::AssetListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/imagekitio/models/asset_list_params.rb,
sig/imagekitio/models/asset_list_params.rbs
Overview
Defined Under Namespace
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Imagekitio
Instance Attribute Summary collapse
-
#file_type ⇒ Symbol, ...
Filter results by file type.
-
#limit ⇒ Integer?
The maximum number of results to return in response.
-
#path ⇒ String?
Folder path if you want to limit the search within a specific folder.
-
#search_query ⇒ String?
Query string in a Lucene-like query language e.g.
-
#skip ⇒ Integer?
The number of results to skip before returning results.
-
#sort ⇒ Symbol, ...
Sort the results by one of the supported fields in ascending or descending order.
-
#type ⇒ Symbol, ...
Filter results by asset type.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(file_type: nil, limit: nil, path: nil, search_query: nil, skip: nil, sort: nil, type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AssetListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file_type: nil, limit: nil, path: nil, search_query: nil, skip: nil, sort: nil, type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Imagekitio::Models::AssetListParams for more details.
|
|
# File 'lib/imagekitio/models/asset_list_params.rb', line 79
|
Instance Attribute Details
#file_type ⇒ Symbol, ...
Filter results by file type.
all— include all file typesimage— include only image filesnon-image— include only non-image files (e.g., JS, CSS, video)
18 |
# File 'lib/imagekitio/models/asset_list_params.rb', line 18 optional :file_type, enum: -> { Imagekitio::AssetListParams::FileType } |
#limit ⇒ Integer?
The maximum number of results to return in response.
24 |
# File 'lib/imagekitio/models/asset_list_params.rb', line 24 optional :limit, Integer |
#path ⇒ String?
Folder path if you want to limit the search within a specific folder. For
example, /sales-banner/ will only search in folder sales-banner.
Note : If your use case involves searching within a folder as well as its
subfolders, you can use path parameter in searchQuery with appropriate
operator. Checkout
Supported parameters
for more information.
37 |
# File 'lib/imagekitio/models/asset_list_params.rb', line 37 optional :path, String |
#search_query ⇒ String?
Query string in a Lucene-like query language e.g. createdAt > "7d".
Note : When the searchQuery parameter is present, the following query parameters will have no effect on the result:
tagstypename
Learn more from examples.
53 |
# File 'lib/imagekitio/models/asset_list_params.rb', line 53 optional :search_query, String |
#skip ⇒ Integer?
The number of results to skip before returning results.
59 |
# File 'lib/imagekitio/models/asset_list_params.rb', line 59 optional :skip, Integer |
#sort ⇒ Symbol, ...
Sort the results by one of the supported fields in ascending or descending order.
66 |
# File 'lib/imagekitio/models/asset_list_params.rb', line 66 optional :sort, enum: -> { Imagekitio::AssetListParams::Sort } |
#type ⇒ Symbol, ...
Filter results by asset type.
file— returns only filesfile-version— returns specific file versionsfolder— returns only foldersall— returns both files and folders (excludesfile-version)
77 |
# File 'lib/imagekitio/models/asset_list_params.rb', line 77 optional :type, enum: -> { Imagekitio::AssetListParams::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/imagekitio/models/asset_list_params.rb', line 111
|
Instance Method Details
#to_hash ⇒ {
64 |
# File 'sig/imagekitio/models/asset_list_params.rbs', line 64
def to_hash: -> {
|