Class: Imagekitio::Models::CustomMetadataFieldCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/imagekitio/models/custom_metadata_field_create_params.rb,
sig/imagekitio/models/custom_metadata_field_create_params.rbs

Overview

See Also:

  • Imagekitio::Resources::CustomMetadataFields#create

Defined Under Namespace

Classes: Schema

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Imagekitio

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



21
# File 'sig/imagekitio/models/custom_metadata_field_create_params.rbs', line 21

def initialize: (

Instance Attribute Details

#labelString

Human readable name of the custom metadata field. This should be unique across all non deleted custom metadata fields. This name is displayed as form field label to the users while setting field value on an asset in the media library UI.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/imagekitio/models/custom_metadata_field_create_params.rb', line 17

required :label, String

#nameString

API name of the custom metadata field. This should be unique across all (including deleted) custom metadata fields.

Parameters:

  • value (String)

Returns:

  • (String)


24
# File 'lib/imagekitio/models/custom_metadata_field_create_params.rb', line 24

required :name, String

#schemaImagekitio::Models::CustomMetadataFieldCreateParams::Schema

Parameters:

  • value (Imagekitio::CustomMetadataFieldCreateParams::Schema)

Returns:



29
# File 'lib/imagekitio/models/custom_metadata_field_create_params.rb', line 29

required :schema, -> { Imagekitio::CustomMetadataFieldCreateParams::Schema }

Instance Method Details

#to_hash{

Returns:

  • ({)


28
# File 'sig/imagekitio/models/custom_metadata_field_create_params.rbs', line 28

def to_hash: -> {