Class: Imagekitio::Models::CustomMetadataFieldUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::CustomMetadataFieldUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/imagekitio/models/custom_metadata_field_update_params.rb,
sig/imagekitio/models/custom_metadata_field_update_params.rbs
Overview
Defined Under Namespace
Classes: Schema
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Imagekitio
Instance Attribute Summary collapse
- #id ⇒ String
-
#label ⇒ String?
Human readable name of the custom metadata field.
-
#schema ⇒ Imagekitio::Models::CustomMetadataFieldUpdateParams::Schema?
An object that describes the rules for the custom metadata key.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
27 |
# File 'sig/imagekitio/models/custom_metadata_field_update_params.rbs', line 27
def initialize: (
|
Instance Attribute Details
#id ⇒ String
13 |
# File 'lib/imagekitio/models/custom_metadata_field_update_params.rb', line 13 required :id, String |
#label ⇒ String?
Human readable name of the custom metadata field. This should be unique across
all non deleted custom metadata fields. This name is displayed as form field
label to the users while setting field value on an asset in the media library
UI. This parameter is required if schema is not provided.
22 |
# File 'lib/imagekitio/models/custom_metadata_field_update_params.rb', line 22 optional :label, String |
#schema ⇒ Imagekitio::Models::CustomMetadataFieldUpdateParams::Schema?
An object that describes the rules for the custom metadata key. This parameter
is required if label is not provided. Note: type cannot be updated and will
be ignored if sent with the schema. The schema will be validated as per the
existing type.
31 |
# File 'lib/imagekitio/models/custom_metadata_field_update_params.rb', line 31 optional :schema, -> { Imagekitio::CustomMetadataFieldUpdateParams::Schema } |
Instance Method Details
#to_hash ⇒ {
34 |
# File 'sig/imagekitio/models/custom_metadata_field_update_params.rbs', line 34
def to_hash: -> {
|