Class: Imagekitio::Models::ExtensionConfig::AITasks::Task::SelectMetadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::ExtensionConfig::AITasks::Task::SelectMetadata
- Defined in:
- lib/imagekitio/models/extension_config.rb
Defined Under Namespace
Modules: Vocabulary
Instance Attribute Summary collapse
-
#field ⇒ String
Name of the custom metadata field to set.
-
#instruction ⇒ String
The question or instruction for the AI to analyze the image.
-
#max_selections ⇒ Integer?
Maximum number of values to select from the vocabulary.
-
#min_selections ⇒ Integer?
Minimum number of values to select from the vocabulary.
-
#type ⇒ Symbol, :select_metadata
Task type that analyzes the image and sets a custom metadata field value from a vocabulary.
-
#vocabulary ⇒ Array<String, Float, Boolean>?
An array of possible values matching the custom metadata field type.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Imagekitio::Internal::Type::BaseModel
Instance Attribute Details
#field ⇒ String
Name of the custom metadata field to set. The field must exist in your account.
218 |
# File 'lib/imagekitio/models/extension_config.rb', line 218 required :field, String |
#instruction ⇒ String
The question or instruction for the AI to analyze the image.
224 |
# File 'lib/imagekitio/models/extension_config.rb', line 224 required :instruction, String |
#max_selections ⇒ Integer?
Maximum number of values to select from the vocabulary.
237 |
# File 'lib/imagekitio/models/extension_config.rb', line 237 optional :max_selections, Integer |
#min_selections ⇒ Integer?
Minimum number of values to select from the vocabulary.
243 |
# File 'lib/imagekitio/models/extension_config.rb', line 243 optional :min_selections, Integer |
#type ⇒ Symbol, :select_metadata
Task type that analyzes the image and sets a custom metadata field value from a vocabulary.
231 |
# File 'lib/imagekitio/models/extension_config.rb', line 231 required :type, const: :select_metadata |
#vocabulary ⇒ Array<String, Float, Boolean>?
An array of possible values matching the custom metadata field type. If not provided for SingleSelect or MultiSelect field types, all values from the custom metadata field definition will be used. When providing large vocabularies (above 30 items), the AI may not strictly adhere to the list.
252 253 |
# File 'lib/imagekitio/models/extension_config.rb', line 252 optional :vocabulary, -> { Imagekitio::Internal::Type::ArrayOf[union: Imagekitio::ExtensionConfig::AITasks::Task::SelectMetadata::Vocabulary] } |