Class: Imagekitio::Models::ExtensionItem::AITasks::Task::SelectMetadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::ExtensionItem::AITasks::Task::SelectMetadata
- Defined in:
- lib/imagekitio/models/extensions.rb
Defined Under Namespace
Modules: Vocabulary
Instance Attribute Summary collapse
-
#field ⇒ String
Name of the custom metadata field to set.
-
#instruction ⇒ String
The question or instruction for the AI to analyze the image.
-
#max_selections ⇒ Integer?
Maximum number of values to select from the vocabulary.
-
#min_selections ⇒ Integer?
Minimum number of values to select from the vocabulary.
-
#type ⇒ Symbol, :select_metadata
Task type that analyzes the image and sets a custom metadata field value from a vocabulary.
-
#vocabulary ⇒ Array<String, Float, Boolean>?
Array of possible values matching the custom metadata field type.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Imagekitio::Internal::Type::BaseModel
Instance Attribute Details
#field ⇒ String
Name of the custom metadata field to set. The field must exist in your account.
215 |
# File 'lib/imagekitio/models/extensions.rb', line 215 required :field, String |
#instruction ⇒ String
The question or instruction for the AI to analyze the image.
221 |
# File 'lib/imagekitio/models/extensions.rb', line 221 required :instruction, String |
#max_selections ⇒ Integer?
Maximum number of values to select from the vocabulary.
234 |
# File 'lib/imagekitio/models/extensions.rb', line 234 optional :max_selections, Integer |
#min_selections ⇒ Integer?
Minimum number of values to select from the vocabulary.
240 |
# File 'lib/imagekitio/models/extensions.rb', line 240 optional :min_selections, Integer |
#type ⇒ Symbol, :select_metadata
Task type that analyzes the image and sets a custom metadata field value from a vocabulary.
228 |
# File 'lib/imagekitio/models/extensions.rb', line 228 required :type, const: :select_metadata |
#vocabulary ⇒ Array<String, Float, Boolean>?
Array of possible values matching the custom metadata field type.
246 247 |
# File 'lib/imagekitio/models/extensions.rb', line 246 optional :vocabulary, -> { Imagekitio::Internal::Type::ArrayOf[union: Imagekitio::ExtensionItem::AITasks::Task::SelectMetadata::Vocabulary] } |