Class: Imagekitio::Models::File
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::File
- Defined in:
- lib/imagekitio/models/file.rb
Overview
Direct Known Subclasses
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#ai_tags ⇒ Array<Imagekitio::Models::AITag>?
Array of AI-generated tags associated with the image.
-
#audio_codec ⇒ String?
The audio codec used in the video (only for video/audio).
-
#bit_rate ⇒ Integer?
The bit rate of the video in kbps (only for video).
-
#created_at ⇒ Time?
Date and time when the file was uploaded.
-
#custom_coordinates ⇒ String?
An string with custom coordinates of the file.
-
#custom_metadata ⇒ Hash{Symbol=>Object}?
An object with custom metadata for the file.
-
#description ⇒ String?
Optional text to describe the contents of the file.
-
#duration ⇒ Integer?
The duration of the video in seconds (only for video).
-
#embedded_metadata ⇒ Hash{Symbol=>Object}?
Consolidated embedded metadata associated with the file.
-
#file_id ⇒ String?
Unique identifier of the asset.
-
#file_path ⇒ String?
Path of the file.
-
#file_type ⇒ String?
Type of the file.
-
#has_alpha ⇒ Boolean?
Specifies if the image has an alpha channel.
-
#height ⇒ Float?
Height of the file.
-
#is_private_file ⇒ Boolean?
Specifies if the file is private or not.
-
#is_published ⇒ Boolean?
Specifies if the file is published or not.
-
#mime ⇒ String?
MIME type of the file.
-
#name ⇒ String?
Name of the asset.
-
#selected_fields_schema ⇒ Hash{Symbol=>Imagekitio::Models::SelectedFieldsSchemaItem}?
This field is included in the response only if the Path policy feature is available in the plan.
-
#size ⇒ Float?
Size of the file in bytes.
-
#tags ⇒ Array<String>?
An array of tags assigned to the file.
-
#thumbnail ⇒ String?
URL of the thumbnail image.
-
#type ⇒ Symbol, ...
Type of the asset.
-
#updated_at ⇒ Time?
Date and time when the file was last updated.
-
#url ⇒ String?
URL of the file.
-
#version_info ⇒ Imagekitio::Models::VersionInfo?
An object with details of the file version.
-
#video_codec ⇒ String?
The video codec used in the video (only for video).
-
#width ⇒ Float?
Width of the file.
Instance Method Summary collapse
-
#initialize(ai_tags: nil, audio_codec: nil, bit_rate: nil, created_at: nil, custom_coordinates: nil, custom_metadata: nil, description: nil, duration: nil, embedded_metadata: nil, file_id: nil, file_path: nil, file_type: nil, has_alpha: nil, height: nil, is_private_file: nil, is_published: nil, mime: nil, name: nil, selected_fields_schema: nil, size: nil, tags: nil, thumbnail: nil, type: nil, updated_at: nil, url: nil, version_info: nil, video_codec: nil, width: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see File for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ai_tags: nil, audio_codec: nil, bit_rate: nil, created_at: nil, custom_coordinates: nil, custom_metadata: nil, description: nil, duration: nil, embedded_metadata: nil, file_id: nil, file_path: nil, file_type: nil, has_alpha: nil, height: nil, is_private_file: nil, is_published: nil, mime: nil, name: nil, selected_fields_schema: nil, size: nil, tags: nil, thumbnail: nil, type: nil, updated_at: nil, url: nil, version_info: nil, video_codec: nil, width: nil) ⇒ Object
Some parameter documentations has been truncated, see Imagekitio::Models::File for more details.
Object containing details of a file or file version.
|
|
# File 'lib/imagekitio/models/file.rb', line 200
|
Instance Attribute Details
#ai_tags ⇒ Array<Imagekitio::Models::AITag>?
Array of AI-generated tags associated with the image. If no AITags are set, it will be null.
12 13 14 15 |
# File 'lib/imagekitio/models/file.rb', line 12 optional :ai_tags, -> { Imagekitio::Internal::Type::ArrayOf[Imagekitio::AITag] }, api_name: :AITags, nil?: true |
#audio_codec ⇒ String?
The audio codec used in the video (only for video/audio).
21 |
# File 'lib/imagekitio/models/file.rb', line 21 optional :audio_codec, String, api_name: :audioCodec |
#bit_rate ⇒ Integer?
The bit rate of the video in kbps (only for video).
27 |
# File 'lib/imagekitio/models/file.rb', line 27 optional :bit_rate, Integer, api_name: :bitRate |
#created_at ⇒ Time?
Date and time when the file was uploaded. The date and time is in ISO8601 format.
34 |
# File 'lib/imagekitio/models/file.rb', line 34 optional :created_at, Time, api_name: :createdAt |
#custom_coordinates ⇒ String?
An string with custom coordinates of the file.
40 |
# File 'lib/imagekitio/models/file.rb', line 40 optional :custom_coordinates, String, api_name: :customCoordinates, nil?: true |
#custom_metadata ⇒ Hash{Symbol=>Object}?
An object with custom metadata for the file.
46 47 48 |
# File 'lib/imagekitio/models/file.rb', line 46 optional :custom_metadata, Imagekitio::Internal::Type::HashOf[Imagekitio::Internal::Type::Unknown], api_name: :customMetadata |
#description ⇒ String?
Optional text to describe the contents of the file. Can be set by the user or the ai-auto-description extension.
55 |
# File 'lib/imagekitio/models/file.rb', line 55 optional :description, String |
#duration ⇒ Integer?
The duration of the video in seconds (only for video).
61 |
# File 'lib/imagekitio/models/file.rb', line 61 optional :duration, Integer |
#embedded_metadata ⇒ Hash{Symbol=>Object}?
Consolidated embedded metadata associated with the file. It includes exif, iptc, and xmp data.
68 69 70 |
# File 'lib/imagekitio/models/file.rb', line 68 optional :embedded_metadata, Imagekitio::Internal::Type::HashOf[Imagekitio::Internal::Type::Unknown], api_name: :embeddedMetadata |
#file_id ⇒ String?
Unique identifier of the asset.
76 |
# File 'lib/imagekitio/models/file.rb', line 76 optional :file_id, String, api_name: :fileId |
#file_path ⇒ String?
Path of the file. This is the path you would use in the URL to access the file. For example, if the file is at the root of the media library, the path will be ‘/file.jpg`. If the file is inside a folder named `images`, the path will be `/images/file.jpg`.
85 |
# File 'lib/imagekitio/models/file.rb', line 85 optional :file_path, String, api_name: :filePath |
#file_type ⇒ String?
Type of the file. Possible values are ‘image`, `non-image`.
91 |
# File 'lib/imagekitio/models/file.rb', line 91 optional :file_type, String, api_name: :fileType |
#has_alpha ⇒ Boolean?
Specifies if the image has an alpha channel.
97 |
# File 'lib/imagekitio/models/file.rb', line 97 optional :has_alpha, Imagekitio::Internal::Type::Boolean, api_name: :hasAlpha |
#height ⇒ Float?
Height of the file.
103 |
# File 'lib/imagekitio/models/file.rb', line 103 optional :height, Float |
#is_private_file ⇒ Boolean?
Specifies if the file is private or not.
109 |
# File 'lib/imagekitio/models/file.rb', line 109 optional :is_private_file, Imagekitio::Internal::Type::Boolean, api_name: :isPrivateFile |
#is_published ⇒ Boolean?
Specifies if the file is published or not.
115 |
# File 'lib/imagekitio/models/file.rb', line 115 optional :is_published, Imagekitio::Internal::Type::Boolean, api_name: :isPublished |
#mime ⇒ String?
MIME type of the file.
121 |
# File 'lib/imagekitio/models/file.rb', line 121 optional :mime, String |
#name ⇒ String?
Name of the asset.
127 |
# File 'lib/imagekitio/models/file.rb', line 127 optional :name, String |
#selected_fields_schema ⇒ Hash{Symbol=>Imagekitio::Models::SelectedFieldsSchemaItem}?
This field is included in the response only if the Path policy feature is available in the plan. It contains schema definitions for the custom metadata fields selected for the specified file path. Field selection can only be done when the Path policy feature is enabled.
Keys are the names of the custom metadata fields; the value object has details about the custom metadata schema.
139 140 141 |
# File 'lib/imagekitio/models/file.rb', line 139 optional :selected_fields_schema, -> { Imagekitio::Internal::Type::HashOf[Imagekitio::SelectedFieldsSchemaItem] }, api_name: :selectedFieldsSchema |
#size ⇒ Float?
Size of the file in bytes.
147 |
# File 'lib/imagekitio/models/file.rb', line 147 optional :size, Float |
#tags ⇒ Array<String>?
An array of tags assigned to the file. Tags are used to search files in the media library.
154 |
# File 'lib/imagekitio/models/file.rb', line 154 optional :tags, Imagekitio::Internal::Type::ArrayOf[String], nil?: true |
#thumbnail ⇒ String?
URL of the thumbnail image. This URL is used to access the thumbnail image of the file in the media library.
161 |
# File 'lib/imagekitio/models/file.rb', line 161 optional :thumbnail, String |
#type ⇒ Symbol, ...
Type of the asset.
167 |
# File 'lib/imagekitio/models/file.rb', line 167 optional :type, enum: -> { Imagekitio::File::Type } |
#updated_at ⇒ Time?
Date and time when the file was last updated. The date and time is in ISO8601 format.
174 |
# File 'lib/imagekitio/models/file.rb', line 174 optional :updated_at, Time, api_name: :updatedAt |
#url ⇒ String?
URL of the file.
180 |
# File 'lib/imagekitio/models/file.rb', line 180 optional :url, String |
#version_info ⇒ Imagekitio::Models::VersionInfo?
An object with details of the file version.
186 |
# File 'lib/imagekitio/models/file.rb', line 186 optional :version_info, -> { Imagekitio::VersionInfo }, api_name: :versionInfo |
#video_codec ⇒ String?
The video codec used in the video (only for video).
192 |
# File 'lib/imagekitio/models/file.rb', line 192 optional :video_codec, String, api_name: :videoCodec |
#width ⇒ Float?
Width of the file.
198 |
# File 'lib/imagekitio/models/file.rb', line 198 optional :width, Float |