Class: Imagekitio::Models::File
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::File
- Defined in:
- lib/imagekitio/models/file.rb
Overview
Direct Known Subclasses
Defined Under Namespace
Modules: Type Classes: AITag, SelectedFieldsSchema, VersionInfo
Instance Attribute Summary collapse
-
#ai_tags ⇒ Array<Imagekitio::Models::File::AITag>?
An array of tags assigned to the file by auto tagging.
-
#audio_codec ⇒ String?
The audio codec used in the video (only for video/audio).
-
#bit_rate ⇒ Integer?
The bit rate of the video in kbps (only for video).
-
#created_at ⇒ Time?
Date and time when the file was uploaded.
-
#custom_coordinates ⇒ String?
An string with custom coordinates of the file.
-
#custom_metadata ⇒ Hash{Symbol=>Object}?
An object with custom metadata for the file.
-
#description ⇒ String?
Optional text to describe the contents of the file.
-
#duration ⇒ Integer?
The duration of the video in seconds (only for video).
-
#embedded_metadata ⇒ Hash{Symbol=>Object}?
Consolidated embedded metadata associated with the file.
-
#file_id ⇒ String?
Unique identifier of the asset.
-
#file_path ⇒ String?
Path of the file.
-
#file_type ⇒ String?
Type of the file.
-
#has_alpha ⇒ Boolean?
Specifies if the image has an alpha channel.
-
#height ⇒ Float?
Height of the file.
-
#is_private_file ⇒ Boolean?
Specifies if the file is private or not.
-
#is_published ⇒ Boolean?
Specifies if the file is published or not.
-
#mime ⇒ String?
MIME type of the file.
-
#name ⇒ String?
Name of the asset.
-
#selected_fields_schema ⇒ Hash{Symbol=>Imagekitio::Models::File::SelectedFieldsSchema}?
This field is included in the response only if the Path policy feature is available in the plan.
-
#size ⇒ Float?
Size of the file in bytes.
-
#tags ⇒ Array<String>?
An array of tags assigned to the file.
-
#thumbnail ⇒ String?
URL of the thumbnail image.
-
#type ⇒ Symbol, ...
Type of the asset.
-
#updated_at ⇒ Time?
Date and time when the file was last updated.
-
#url ⇒ String?
URL of the file.
-
#version_info ⇒ Imagekitio::Models::File::VersionInfo?
An object with details of the file version.
-
#video_codec ⇒ String?
The video codec used in the video (only for video).
-
#width ⇒ Float?
Width of the file.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(confidence: nil, name: nil, source: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AITag for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(confidence: nil, name: nil, source: nil) ⇒ Object
Some parameter documentations has been truncated, see AITag for more details.
|
|
# File 'lib/imagekitio/models/file.rb', line 281
|
Instance Attribute Details
#ai_tags ⇒ Array<Imagekitio::Models::File::AITag>?
An array of tags assigned to the file by auto tagging.
11 12 13 14 |
# File 'lib/imagekitio/models/file.rb', line 11 optional :ai_tags, -> { Imagekitio::Internal::Type::ArrayOf[Imagekitio::File::AITag] }, api_name: :AITags, nil?: true |
#audio_codec ⇒ String?
The audio codec used in the video (only for video/audio).
20 |
# File 'lib/imagekitio/models/file.rb', line 20 optional :audio_codec, String, api_name: :audioCodec |
#bit_rate ⇒ Integer?
The bit rate of the video in kbps (only for video).
26 |
# File 'lib/imagekitio/models/file.rb', line 26 optional :bit_rate, Integer, api_name: :bitRate |
#created_at ⇒ Time?
Date and time when the file was uploaded. The date and time is in ISO8601 format.
33 |
# File 'lib/imagekitio/models/file.rb', line 33 optional :created_at, Time, api_name: :createdAt |
#custom_coordinates ⇒ String?
An string with custom coordinates of the file.
39 |
# File 'lib/imagekitio/models/file.rb', line 39 optional :custom_coordinates, String, api_name: :customCoordinates, nil?: true |
#custom_metadata ⇒ Hash{Symbol=>Object}?
An object with custom metadata for the file.
45 46 47 |
# File 'lib/imagekitio/models/file.rb', line 45 optional :custom_metadata, Imagekitio::Internal::Type::HashOf[Imagekitio::Internal::Type::Unknown], api_name: :customMetadata |
#description ⇒ String?
Optional text to describe the contents of the file. Can be set by the user or the ai-auto-description extension.
54 |
# File 'lib/imagekitio/models/file.rb', line 54 optional :description, String |
#duration ⇒ Integer?
The duration of the video in seconds (only for video).
60 |
# File 'lib/imagekitio/models/file.rb', line 60 optional :duration, Integer |
#embedded_metadata ⇒ Hash{Symbol=>Object}?
Consolidated embedded metadata associated with the file. It includes exif, iptc, and xmp data.
67 68 69 |
# File 'lib/imagekitio/models/file.rb', line 67 optional :embedded_metadata, Imagekitio::Internal::Type::HashOf[Imagekitio::Internal::Type::Unknown], api_name: :embeddedMetadata |
#file_id ⇒ String?
Unique identifier of the asset.
75 |
# File 'lib/imagekitio/models/file.rb', line 75 optional :file_id, String, api_name: :fileId |
#file_path ⇒ String?
Path of the file. This is the path you would use in the URL to access the file. For example, if the file is at the root of the media library, the path will be /file.jpg. If the file is inside a folder named images, the path will be /images/file.jpg.
84 |
# File 'lib/imagekitio/models/file.rb', line 84 optional :file_path, String, api_name: :filePath |
#file_type ⇒ String?
Type of the file. Possible values are image, non-image.
90 |
# File 'lib/imagekitio/models/file.rb', line 90 optional :file_type, String, api_name: :fileType |
#has_alpha ⇒ Boolean?
Specifies if the image has an alpha channel.
96 |
# File 'lib/imagekitio/models/file.rb', line 96 optional :has_alpha, Imagekitio::Internal::Type::Boolean, api_name: :hasAlpha |
#height ⇒ Float?
Height of the file.
102 |
# File 'lib/imagekitio/models/file.rb', line 102 optional :height, Float |
#is_private_file ⇒ Boolean?
Specifies if the file is private or not.
108 |
# File 'lib/imagekitio/models/file.rb', line 108 optional :is_private_file, Imagekitio::Internal::Type::Boolean, api_name: :isPrivateFile |
#is_published ⇒ Boolean?
Specifies if the file is published or not.
114 |
# File 'lib/imagekitio/models/file.rb', line 114 optional :is_published, Imagekitio::Internal::Type::Boolean, api_name: :isPublished |
#mime ⇒ String?
MIME type of the file.
120 |
# File 'lib/imagekitio/models/file.rb', line 120 optional :mime, String |
#name ⇒ String?
Name of the asset.
126 |
# File 'lib/imagekitio/models/file.rb', line 126 optional :name, String |
#selected_fields_schema ⇒ Hash{Symbol=>Imagekitio::Models::File::SelectedFieldsSchema}?
This field is included in the response only if the Path policy feature is available in the plan. It contains schema definitions for the custom metadata fields selected for the specified file path. Field selection can only be done when the Path policy feature is enabled.
Keys are the names of the custom metadata fields; the value object has details about the custom metadata schema.
138 139 140 |
# File 'lib/imagekitio/models/file.rb', line 138 optional :selected_fields_schema, -> { Imagekitio::Internal::Type::HashOf[Imagekitio::File::SelectedFieldsSchema] }, api_name: :selectedFieldsSchema |
#size ⇒ Float?
Size of the file in bytes.
146 |
# File 'lib/imagekitio/models/file.rb', line 146 optional :size, Float |
#tags ⇒ Array<String>?
An array of tags assigned to the file. Tags are used to search files in the media library.
153 |
# File 'lib/imagekitio/models/file.rb', line 153 optional :tags, Imagekitio::Internal::Type::ArrayOf[String], nil?: true |
#thumbnail ⇒ String?
URL of the thumbnail image. This URL is used to access the thumbnail image of the file in the media library.
160 |
# File 'lib/imagekitio/models/file.rb', line 160 optional :thumbnail, String |
#type ⇒ Symbol, ...
Type of the asset.
166 |
# File 'lib/imagekitio/models/file.rb', line 166 optional :type, enum: -> { Imagekitio::File::Type } |
#updated_at ⇒ Time?
Date and time when the file was last updated. The date and time is in ISO8601 format.
173 |
# File 'lib/imagekitio/models/file.rb', line 173 optional :updated_at, Time, api_name: :updatedAt |
#url ⇒ String?
URL of the file.
179 |
# File 'lib/imagekitio/models/file.rb', line 179 optional :url, String |
#version_info ⇒ Imagekitio::Models::File::VersionInfo?
An object with details of the file version.
185 |
# File 'lib/imagekitio/models/file.rb', line 185 optional :version_info, -> { Imagekitio::File::VersionInfo }, api_name: :versionInfo |
#video_codec ⇒ String?
The video codec used in the video (only for video).
191 |
# File 'lib/imagekitio/models/file.rb', line 191 optional :video_codec, String, api_name: :videoCodec |
#width ⇒ Float?
Width of the file.
197 |
# File 'lib/imagekitio/models/file.rb', line 197 optional :width, Float |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/imagekitio/models/file.rb', line 513
|
.variants ⇒ Array(String, Float, Boolean)
|
|
# File 'lib/imagekitio/models/file.rb', line 499
|