Class: Imagekitio::Models::FileUpdateEvent
- Inherits:
-
BaseWebhookEvent
- Object
- Internal::Type::BaseModel
- BaseWebhookEvent
- Imagekitio::Models::FileUpdateEvent
- Defined in:
- lib/imagekitio/models/file_update_event.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Time
Timestamp of when the event occurred in ISO8601 format.
-
#data ⇒ Imagekitio::Models::File
Object containing details of a file or file version.
-
#type ⇒ Symbol, :"file.updated"
Type of the webhook event.
Attributes inherited from BaseWebhookEvent
Instance Method Summary collapse
-
#initialize(created_at:, data:, type: :"file.updated") ⇒ Object
constructor
Triggered when a file is updated.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(created_at:, data:, type: :"file.updated") ⇒ Object
Triggered when a file is updated.
|
|
# File 'lib/imagekitio/models/file_update_event.rb', line 24
|
Instance Attribute Details
#created_at ⇒ Time
Timestamp of when the event occurred in ISO8601 format.
10 |
# File 'lib/imagekitio/models/file_update_event.rb', line 10 required :created_at, Time |
#data ⇒ Imagekitio::Models::File
Object containing details of a file or file version.
16 |
# File 'lib/imagekitio/models/file_update_event.rb', line 16 required :data, -> { Imagekitio::File } |
#type ⇒ Symbol, :"file.updated"
Type of the webhook event.
22 |
# File 'lib/imagekitio/models/file_update_event.rb', line 22 required :type, const: :"file.updated" |