Class: Imagekitio::Models::ImageOverlay
- Inherits:
-
BaseOverlay
- Object
- Internal::Type::BaseModel
- BaseOverlay
- Imagekitio::Models::ImageOverlay
- Defined in:
- lib/imagekitio/models/image_overlay.rb
Defined Under Namespace
Modules: Encoding
Instance Attribute Summary collapse
-
#encoding ⇒ Symbol, ...
The input path can be included in the layer as either ‘i-#input` or `ie-base64_encoded_input`.
-
#input ⇒ String
Specifies the relative path to the image used as an overlay.
-
#transformation ⇒ Array<Imagekitio::Models::Transformation>?
Array of transformations to be applied to the overlay image.
- #type ⇒ Symbol, :image
Attributes inherited from BaseOverlay
#layer_mode, #position, #timing
Instance Method Summary collapse
-
#initialize(input:, encoding: nil, transformation: nil, type: :image) ⇒ Object
constructor
Some parameter documentations has been truncated, see ImageOverlay for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(input:, encoding: nil, transformation: nil, type: :image) ⇒ Object
Some parameter documentations has been truncated, see Imagekitio::Models::ImageOverlay for more details.
|
|
# File 'lib/imagekitio/models/image_overlay.rb', line 43
|
Instance Attribute Details
#encoding ⇒ Symbol, ...
The input path can be included in the layer as either ‘i-#input` or `ie-base64_encoded_input`. By default, the SDK determines the appropriate format automatically. To always use base64 encoding (`ie-base64`), set this parameter to base64. To always use plain text (`i-#input`), set it to plain.
Regardless of the encoding method:
-
Leading and trailing slashes are removed.
-
Remaining slashes within the path are replaced with ‘@@` when using plain text.
31 |
# File 'lib/imagekitio/models/image_overlay.rb', line 31 optional :encoding, enum: -> { Imagekitio::ImageOverlay::Encoding } |
#input ⇒ String
Specifies the relative path to the image used as an overlay.
10 |
# File 'lib/imagekitio/models/image_overlay.rb', line 10 required :input, String |
#transformation ⇒ Array<Imagekitio::Models::Transformation>?
Array of transformations to be applied to the overlay image. Supported transformations depends on the base/parent asset. See overlays on [Images](imagekit.io/docs/add-overlays-on-images#list-of-supported-image-transformations-in-image-layers) and [Videos](imagekit.io/docs/add-overlays-on-videos#list-of-transformations-supported-on-image-overlay).
41 |
# File 'lib/imagekitio/models/image_overlay.rb', line 41 optional :transformation, -> { Imagekitio::Internal::Type::ArrayOf[Imagekitio::Transformation] } |
#type ⇒ Symbol, :image
15 |
# File 'lib/imagekitio/models/image_overlay.rb', line 15 required :type, const: :image |