Class: Imagekitio::Models::NamedTransformation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::NamedTransformation
- Defined in:
- lib/imagekitio/models/named_transformation.rb,
sig/imagekitio/models/named_transformation.rbs
Instance Attribute Summary collapse
-
#created_at ⇒ Time
ISO 8601 timestamp of when the named transformation was created.
-
#enabled ⇒ Boolean
Whether the named transformation is currently enabled.
-
#id ⇒ String
Unique identifier for a named transformation.
-
#name ⇒ String
Alias for the transformation string, used in URLs as
tr:n-<name>. -
#transformation ⇒ String
The transformation string this named transformation refers to.
Instance Method Summary collapse
-
#initialize(id:, created_at:, enabled:, name:, transformation:) ⇒ Object
constructor
Some parameter documentations has been truncated, see NamedTransformation for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, enabled:, name:, transformation:) ⇒ Object
Some parameter documentations has been truncated, see Imagekitio::Models::NamedTransformation for more details.
A named transformation is an alias for a transformation string, letting you apply and later update complex transformations without changing your image or video URLs. Learn more about named transformations.
|
|
# File 'lib/imagekitio/models/named_transformation.rb', line 40
|
Instance Attribute Details
#created_at ⇒ Time
ISO 8601 timestamp of when the named transformation was created.
16 |
# File 'lib/imagekitio/models/named_transformation.rb', line 16 required :created_at, Time, api_name: :createdAt |
#enabled ⇒ Boolean
Whether the named transformation is currently enabled. When set to false,
requests using this named transformation fail at delivery time.
23 |
# File 'lib/imagekitio/models/named_transformation.rb', line 23 required :enabled, Imagekitio::Internal::Type::Boolean |
#id ⇒ String
Unique identifier for a named transformation.
10 |
# File 'lib/imagekitio/models/named_transformation.rb', line 10 required :id, String |
#name ⇒ String
Alias for the transformation string, used in URLs as tr:n-<name>. This is
case-sensitive, contains only alphanumeric characters or _ (underscore), and
is unique across all named transformations for your account.
31 |
# File 'lib/imagekitio/models/named_transformation.rb', line 31 required :name, String |
#transformation ⇒ String
The transformation string this named transformation refers to. Learn more about the transformation string syntax.
38 |
# File 'lib/imagekitio/models/named_transformation.rb', line 38 required :transformation, String |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/imagekitio/models/named_transformation.rbs', line 31
def to_hash: -> {
|