Module: Imagekitio::Models::OverlayPosition::AnchorPoint
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/imagekitio/models/overlay_position.rb
Overview
Sets the anchor point on the base asset from which the overlay offset is calculated. The default value is ‘top_left`. Maps to `lap` in the URL. Can only be used with one or more of `x`, `y`, `xCenter`, or `yCenter`.
Constant Summary collapse
- TOP =
:top- LEFT =
:left- RIGHT =
:right- BOTTOM =
:bottom- TOP_LEFT =
:top_left- TOP_RIGHT =
:top_right- BOTTOM_LEFT =
:bottom_left- BOTTOM_RIGHT =
:bottom_right- CENTER =
:center
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info