Module: Imagekitio::Models::SelectedFieldsSchemaItem::MinValue
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/imagekitio/models/selected_fields_schema.rb,
sig/imagekitio/models/selected_fields_schema.rbs
Overview
Minimum value of the field. Only set if field type is Date or Number. For
Date type field, the value will be in ISO8601 string format. For Number type
field, it will be a numeric value.
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.variants ⇒ ::Array[Imagekitio::Models::SelectedFieldsSchemaItem::min_value]
148 |
# File 'sig/imagekitio/models/selected_fields_schema.rbs', line 148
def self?.variants: -> ::Array[Imagekitio::Models::SelectedFieldsSchemaItem::min_value]
|