Class: Imagekitio::Models::SubtitleOverlayTransformation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::SubtitleOverlayTransformation
- Defined in:
- lib/imagekitio/models/subtitle_overlay_transformation.rb
Defined Under Namespace
Modules: Typography
Instance Attribute Summary collapse
-
#background ⇒ String?
Specifies the subtitle background color using a standard color name, an RGB color code (e.g., FF0000), or an RGBA color code (e.g., FFAABB50).
-
#color ⇒ String?
Sets the font color of the subtitle text using a standard color name, an RGB color code (e.g., FF0000), or an RGBA color code (e.g., FFAABB50).
-
#font_family ⇒ String?
Sets the font family of subtitle text.
-
#font_outline ⇒ String?
Sets the font outline of the subtitle text.
-
#font_shadow ⇒ String?
Sets the font shadow for the subtitle text.
-
#font_size ⇒ Float?
Sets the font size of subtitle text.
-
#typography ⇒ Symbol, ...
Sets the typography style of the subtitle text.
Instance Method Summary collapse
-
#initialize(background: nil, color: nil, font_family: nil, font_outline: nil, font_shadow: nil, font_size: nil, typography: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SubtitleOverlayTransformation for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(background: nil, color: nil, font_family: nil, font_outline: nil, font_shadow: nil, font_size: nil, typography: nil) ⇒ Object
Some parameter documentations has been truncated, see Imagekitio::Models::SubtitleOverlayTransformation for more details.
Subtitle styling options. [Learn more](imagekit.io/docs/add-overlays-on-videos#styling-controls-for-subtitles-layer) from the docs.
|
|
# File 'lib/imagekitio/models/subtitle_overlay_transformation.rb', line 74
|
Instance Attribute Details
#background ⇒ String?
Specifies the subtitle background color using a standard color name, an RGB color code (e.g., FF0000), or an RGBA color code (e.g., FFAABB50).
[Subtitle styling options](imagekit.io/docs/add-overlays-on-videos#styling-controls-for-subtitles-layer)
13 |
# File 'lib/imagekitio/models/subtitle_overlay_transformation.rb', line 13 optional :background, String |
#color ⇒ String?
Sets the font color of the subtitle text using a standard color name, an RGB color code (e.g., FF0000), or an RGBA color code (e.g., FFAABB50).
[Subtitle styling options](imagekit.io/docs/add-overlays-on-videos#styling-controls-for-subtitles-layer)
22 |
# File 'lib/imagekitio/models/subtitle_overlay_transformation.rb', line 22 optional :color, String |
#font_family ⇒ String?
Sets the font family of subtitle text. Refer to the [supported fonts documented](imagekit.io/docs/add-overlays-on-images#supported-text-font-list) in the ImageKit transformations guide.
30 |
# File 'lib/imagekitio/models/subtitle_overlay_transformation.rb', line 30 optional :font_family, String, api_name: :fontFamily |
#font_outline ⇒ String?
Sets the font outline of the subtitle text. Requires the outline width (an integer) and the outline color (as an RGB color code, RGBA color code, or standard web color name) separated by an underscore. Example: fol-2_blue (outline width of 2px and outline color blue), fol-2_A1CCDD (outline width of 2px and outline color #A1CCDD) and fol-2_A1CCDD50 (outline width of 2px and outline color #A1CCDD at 50% opacity).
[Subtitle styling options](imagekit.io/docs/add-overlays-on-videos#styling-controls-for-subtitles-layer)
43 |
# File 'lib/imagekitio/models/subtitle_overlay_transformation.rb', line 43 optional :font_outline, String, api_name: :fontOutline |
#font_shadow ⇒ String?
Sets the font shadow for the subtitle text. Requires the shadow color (as an RGB color code, RGBA color code, or standard web color name) and shadow indent (an integer) separated by an underscore. Example: fsh-blue_2 (shadow color blue, indent of 2px), fsh-A1CCDD_3 (shadow color #A1CCDD, indent of 3px), fsh-A1CCDD50_3 (shadow color #A1CCDD at 50% opacity, indent of 3px).
[Subtitle styling options](imagekit.io/docs/add-overlays-on-videos#styling-controls-for-subtitles-layer)
55 |
# File 'lib/imagekitio/models/subtitle_overlay_transformation.rb', line 55 optional :font_shadow, String, api_name: :fontShadow |
#font_size ⇒ Float?
Sets the font size of subtitle text.
[Subtitle styling options](imagekit.io/docs/add-overlays-on-videos#styling-controls-for-subtitles-layer)
63 |
# File 'lib/imagekitio/models/subtitle_overlay_transformation.rb', line 63 optional :font_size, Float, api_name: :fontSize |
#typography ⇒ Symbol, ...
Sets the typography style of the subtitle text. Supports values are b for bold, i for italics, and b_i for bold with italics.
[Subtitle styling options](imagekit.io/docs/add-overlays-on-videos#styling-controls-for-subtitles-layer)
72 |
# File 'lib/imagekitio/models/subtitle_overlay_transformation.rb', line 72 optional :typography, enum: -> { Imagekitio::SubtitleOverlayTransformation::Typography } |