Class: Imagekitio::Models::TextOverlay
- Inherits:
-
BaseOverlay
- Object
- Internal::Type::BaseModel
- BaseOverlay
- Imagekitio::Models::TextOverlay
- Defined in:
- lib/imagekitio/models/text_overlay.rb,
sig/imagekitio/models/text_overlay.rbs
Defined Under Namespace
Modules: Encoding
Constant Summary
Constants inherited from BaseOverlay
Instance Attribute Summary collapse
-
#encoding ⇒ Symbol, ...
Text can be included in the layer as either
i-{input}(plain text) orie-{base64_encoded_input}(base64). -
#text ⇒ String
Specifies the text to be displayed in the overlay.
-
#transformation ⇒ Array<Imagekitio::Models::TextOverlayTransformation>?
Control styling of the text overlay.
- #type ⇒ Symbol, :text
Attributes inherited from BaseOverlay
#layer_mode, #position, #timing
Instance Method Summary collapse
- #`type` ⇒ :text
-
#initialize(text:, encoding: nil, transformation: nil, type: :text) ⇒ Object
constructor
Some parameter documentations has been truncated, see TextOverlay for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(text:, encoding: nil, transformation: nil, type: :text) ⇒ Object
Some parameter documentations has been truncated, see Imagekitio::Models::TextOverlay for more details.
|
|
# File 'lib/imagekitio/models/text_overlay.rb', line 39
|
Instance Attribute Details
#encoding ⇒ Symbol, ...
Text can be included in the layer as either i-{input} (plain text) or
ie-{base64_encoded_input} (base64). By default, the SDK selects the
appropriate format based on the input text. To always use base64
(ie-{base64}), set this parameter to base64. To always use plain text
(i-{input}), set it to plain.
Regardless of the encoding method, the input text is always percent-encoded to ensure it is URL-safe.
29 |
# File 'lib/imagekitio/models/text_overlay.rb', line 29 optional :encoding, enum: -> { Imagekitio::TextOverlay::Encoding } |
#text ⇒ String
Specifies the text to be displayed in the overlay. The SDK automatically handles special characters and encoding.
11 |
# File 'lib/imagekitio/models/text_overlay.rb', line 11 required :text, String |
#transformation ⇒ Array<Imagekitio::Models::TextOverlayTransformation>?
Control styling of the text overlay. See Text overlays.
36 37 |
# File 'lib/imagekitio/models/text_overlay.rb', line 36 optional :transformation, -> { Imagekitio::Internal::Type::ArrayOf[Imagekitio::TextOverlayTransformation] } |
#type ⇒ Symbol, :text
16 |
# File 'lib/imagekitio/models/text_overlay.rb', line 16 required :type, const: :text |
Instance Method Details
#`type` ⇒ :text
16 |
# File 'sig/imagekitio/models/text_overlay.rbs', line 16
def `type`: -> :text
|
#to_hash ⇒ {
39 |
# File 'sig/imagekitio/models/text_overlay.rbs', line 39
def to_hash: -> {
|