Module: Imagekitio::Models::Transformation::AIDropShadow
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/imagekitio/models/transformation.rb,
sig/imagekitio/models/transformation.rbs
Overview
Adds an AI-based drop shadow around a foreground object on a transparent or
removed background. Optionally, control the direction, elevation, and saturation
of the light source (e.g., az-45 to change light direction). Pass true for
the default drop shadow, or provide a string for a custom drop shadow. Supported
inside overlay. See
AI Drop Shadow.
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.variants ⇒ ::Array[Imagekitio::Models::Transformation::ai_drop_shadow]
470 |
# File 'sig/imagekitio/models/transformation.rbs', line 470
def self?.variants: -> ::Array[Imagekitio::Models::Transformation::ai_drop_shadow]
|