Module: Imagekitio::Models::Transformation::Format
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/imagekitio/models/transformation.rb,
sig/imagekitio/models/transformation.rbs
Overview
Specifies the output format for images or videos, e.g., jpg, png, webp,
mp4, or auto. You can also pass orig for images to return the original
format. ImageKit automatically delivers images and videos in the optimal format
based on device support unless overridden by the dashboard settings or the
format parameter. See
Image format and
Video format.
Constant Summary collapse
- AUTO =
:auto- WEBP =
:webp- JPG =
:jpg- JPEG =
:jpeg- PNG =
:png- GIF =
:gif- SVG =
:svg- MP4 =
:mp4- WEBM =
:webm- AVIF =
:avif- ORIG =
:orig
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Imagekitio::Models::Transformation::format_]
650 |
# File 'sig/imagekitio/models/transformation.rbs', line 650
def self?.values: -> ::Array[Imagekitio::Models::Transformation::format_]
|