Class: Imagekitio::Models::UploadPreTransformSuccessEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::UploadPreTransformSuccessEvent::Data
- Defined in:
- lib/imagekitio/models/upload_pre_transform_success_event.rb
Defined Under Namespace
Classes: ExtensionStatus
Instance Attribute Summary collapse
-
#ai_tags ⇒ Array<Imagekitio::Models::AITag>?
An array of tags assigned to the uploaded file by auto tagging.
-
#audio_codec ⇒ String?
The audio codec used in the video (only for video).
-
#bit_rate ⇒ Integer?
The bit rate of the video in kbps (only for video).
-
#custom_coordinates ⇒ String?
Value of custom coordinates associated with the image in the format ‘x,y,width,height`.
-
#custom_metadata ⇒ Hash{Symbol=>Object}?
A key-value data associated with the asset.
-
#description ⇒ String?
Optional text to describe the contents of the file.
-
#duration ⇒ Integer?
The duration of the video in seconds (only for video).
-
#embedded_metadata ⇒ Hash{Symbol=>Object}?
Consolidated embedded metadata associated with the file.
-
#extension_status ⇒ Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus?
Extension names with their processing status at the time of completion of the request.
-
#file_id ⇒ String?
Unique fileId.
-
#file_path ⇒ String?
The relative path of the file in the media library e.g.
-
#file_type ⇒ String?
Type of the uploaded file.
-
#height ⇒ Float?
Height of the image in pixels (Only for images).
-
#is_private_file ⇒ Boolean?
Is the file marked as private.
-
#is_published ⇒ Boolean?
Is the file published or in draft state.
-
#metadata ⇒ Imagekitio::Models::Metadata?
Legacy metadata.
-
#name ⇒ String?
Name of the asset.
-
#selected_fields_schema ⇒ Hash{Symbol=>Imagekitio::Models::SelectedFieldsSchemaItem}?
This field is included in the response only if the Path policy feature is available in the plan.
-
#size ⇒ Float?
Size of the image file in Bytes.
-
#tags ⇒ Array<String>?
The array of tags associated with the asset.
-
#thumbnail_url ⇒ String?
In the case of an image, a small thumbnail URL.
-
#url ⇒ String?
A publicly accessible URL of the file.
-
#version_info ⇒ Imagekitio::Models::VersionInfo?
An object containing the file or file version’s ‘id` (versionId) and `name`.
-
#video_codec ⇒ String?
The video codec used in the video (only for video).
-
#width ⇒ Float?
Width of the image in pixels (Only for Images).
Instance Method Summary collapse
-
#initialize(ai_tags: nil, audio_codec: nil, bit_rate: nil, custom_coordinates: nil, custom_metadata: nil, description: nil, duration: nil, embedded_metadata: nil, extension_status: nil, file_id: nil, file_path: nil, file_type: nil, height: nil, is_private_file: nil, is_published: nil, metadata: nil, name: nil, selected_fields_schema: nil, size: nil, tags: nil, thumbnail_url: nil, url: nil, version_info: nil, video_codec: nil, width: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ai_tags: nil, audio_codec: nil, bit_rate: nil, custom_coordinates: nil, custom_metadata: nil, description: nil, duration: nil, embedded_metadata: nil, extension_status: nil, file_id: nil, file_path: nil, file_type: nil, height: nil, is_private_file: nil, is_published: nil, metadata: nil, name: nil, selected_fields_schema: nil, size: nil, tags: nil, thumbnail_url: nil, url: nil, version_info: nil, video_codec: nil, width: nil) ⇒ Object
Some parameter documentations has been truncated, see Imagekitio::Models::UploadPreTransformSuccessEvent::Data for more details.
Object containing details of a successful upload.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 41 class Data < Imagekitio::Internal::Type::BaseModel # @!attribute ai_tags # An array of tags assigned to the uploaded file by auto tagging. # # @return [Array<Imagekitio::Models::AITag>, nil] optional :ai_tags, -> { Imagekitio::Internal::Type::ArrayOf[Imagekitio::AITag] }, api_name: :AITags, nil?: true # @!attribute audio_codec # The audio codec used in the video (only for video). # # @return [String, nil] optional :audio_codec, String, api_name: :audioCodec # @!attribute bit_rate # The bit rate of the video in kbps (only for video). # # @return [Integer, nil] optional :bit_rate, Integer, api_name: :bitRate # @!attribute custom_coordinates # Value of custom coordinates associated with the image in the format # `x,y,width,height`. If `customCoordinates` are not defined, then it is `null`. # Send `customCoordinates` in `responseFields` in API request to get the value of # this field. # # @return [String, nil] optional :custom_coordinates, String, api_name: :customCoordinates, nil?: true # @!attribute custom_metadata # A key-value data associated with the asset. Use `responseField` in API request # to get `customMetadata` in the upload API response. Before setting any custom # metadata on an asset, you have to create the field using custom metadata fields # API. Send `customMetadata` in `responseFields` in API request to get the value # of this field. # # @return [Hash{Symbol=>Object}, nil] optional :custom_metadata, Imagekitio::Internal::Type::HashOf[Imagekitio::Internal::Type::Unknown], api_name: :customMetadata # @!attribute description # Optional text to describe the contents of the file. Can be set by the user or # the ai-auto-description extension. # # @return [String, nil] optional :description, String # @!attribute duration # The duration of the video in seconds (only for video). # # @return [Integer, nil] optional :duration, Integer # @!attribute embedded_metadata # Consolidated embedded metadata associated with the file. It includes exif, iptc, # and xmp data. Send `embeddedMetadata` in `responseFields` in API request to get # embeddedMetadata in the upload API response. # # @return [Hash{Symbol=>Object}, nil] optional :embedded_metadata, Imagekitio::Internal::Type::HashOf[Imagekitio::Internal::Type::Unknown], api_name: :embeddedMetadata # @!attribute extension_status # Extension names with their processing status at the time of completion of the # request. It could have one of the following status values: # # `success`: The extension has been successfully applied. `failed`: The extension # has failed and will not be retried. `pending`: The extension will finish # processing in some time. On completion, the final status (success / failed) will # be sent to the `webhookUrl` provided. # # If no extension was requested, then this parameter is not returned. # # @return [Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus, nil] optional :extension_status, -> { Imagekitio::UploadPreTransformSuccessEvent::Data::ExtensionStatus }, api_name: :extensionStatus # @!attribute file_id # Unique fileId. Store this fileld in your database, as this will be used to # perform update action on this file. # # @return [String, nil] optional :file_id, String, api_name: :fileId # @!attribute file_path # The relative path of the file in the media library e.g. # `/marketing-assets/new-banner.jpg`. # # @return [String, nil] optional :file_path, String, api_name: :filePath # @!attribute file_type # Type of the uploaded file. Possible values are `image`, `non-image`. # # @return [String, nil] optional :file_type, String, api_name: :fileType # @!attribute height # Height of the image in pixels (Only for images) # # @return [Float, nil] optional :height, Float # @!attribute is_private_file # Is the file marked as private. It can be either `true` or `false`. Send # `isPrivateFile` in `responseFields` in API request to get the value of this # field. # # @return [Boolean, nil] optional :is_private_file, Imagekitio::Internal::Type::Boolean, api_name: :isPrivateFile # @!attribute is_published # Is the file published or in draft state. It can be either `true` or `false`. # Send `isPublished` in `responseFields` in API request to get the value of this # field. # # @return [Boolean, nil] optional :is_published, Imagekitio::Internal::Type::Boolean, api_name: :isPublished # @!attribute metadata # Legacy metadata. Send `metadata` in `responseFields` in API request to get # metadata in the upload API response. # # @return [Imagekitio::Models::Metadata, nil] optional :metadata, -> { Imagekitio::Metadata } # @!attribute name # Name of the asset. # # @return [String, nil] optional :name, String # @!attribute selected_fields_schema # This field is included in the response only if the Path policy feature is # available in the plan. It contains schema definitions for the custom metadata # fields selected for the specified file path. Field selection can only be done # when the Path policy feature is enabled. # # Keys are the names of the custom metadata fields; the value object has details # about the custom metadata schema. # # @return [Hash{Symbol=>Imagekitio::Models::SelectedFieldsSchemaItem}, nil] optional :selected_fields_schema, -> { Imagekitio::Internal::Type::HashOf[Imagekitio::SelectedFieldsSchemaItem] }, api_name: :selectedFieldsSchema # @!attribute size # Size of the image file in Bytes. # # @return [Float, nil] optional :size, Float # @!attribute tags # The array of tags associated with the asset. If no tags are set, it will be # `null`. Send `tags` in `responseFields` in API request to get the value of this # field. # # @return [Array<String>, nil] optional :tags, Imagekitio::Internal::Type::ArrayOf[String], nil?: true # @!attribute thumbnail_url # In the case of an image, a small thumbnail URL. # # @return [String, nil] optional :thumbnail_url, String, api_name: :thumbnailUrl # @!attribute url # A publicly accessible URL of the file. # # @return [String, nil] optional :url, String # @!attribute version_info # An object containing the file or file version's `id` (versionId) and `name`. # # @return [Imagekitio::Models::VersionInfo, nil] optional :version_info, -> { Imagekitio::VersionInfo }, api_name: :versionInfo # @!attribute video_codec # The video codec used in the video (only for video). # # @return [String, nil] optional :video_codec, String, api_name: :videoCodec # @!attribute width # Width of the image in pixels (Only for Images) # # @return [Float, nil] optional :width, Float # @!method initialize(ai_tags: nil, audio_codec: nil, bit_rate: nil, custom_coordinates: nil, custom_metadata: nil, description: nil, duration: nil, embedded_metadata: nil, extension_status: nil, file_id: nil, file_path: nil, file_type: nil, height: nil, is_private_file: nil, is_published: nil, metadata: nil, name: nil, selected_fields_schema: nil, size: nil, tags: nil, thumbnail_url: nil, url: nil, version_info: nil, video_codec: nil, width: nil) # Some parameter documentations has been truncated, see # {Imagekitio::Models::UploadPreTransformSuccessEvent::Data} for more details. # # Object containing details of a successful upload. # # @param ai_tags [Array<Imagekitio::Models::AITag>, nil] An array of tags assigned to the uploaded file by auto tagging. # # @param audio_codec [String] The audio codec used in the video (only for video). # # @param bit_rate [Integer] The bit rate of the video in kbps (only for video). # # @param custom_coordinates [String, nil] Value of custom coordinates associated with the image in the format `x,y,width,h # # @param custom_metadata [Hash{Symbol=>Object}] A key-value data associated with the asset. Use `responseField` in API request t # # @param description [String] Optional text to describe the contents of the file. Can be set by the user or th # # @param duration [Integer] The duration of the video in seconds (only for video). # # @param embedded_metadata [Hash{Symbol=>Object}] Consolidated embedded metadata associated with the file. It includes exif, iptc, # # @param extension_status [Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus] Extension names with their processing status at the time of completion of the re # # @param file_id [String] Unique fileId. Store this fileld in your database, as this will be used to perfo # # @param file_path [String] The relative path of the file in the media library e.g. `/marketing-assets/new-b # # @param file_type [String] Type of the uploaded file. Possible values are `image`, `non-image`. # # @param height [Float] Height of the image in pixels (Only for images) # # @param is_private_file [Boolean] Is the file marked as private. It can be either `true` or `false`. Send `isPriva # # @param is_published [Boolean] Is the file published or in draft state. It can be either `true` or `false`. Sen # # @param metadata [Imagekitio::Models::Metadata] Legacy metadata. Send `metadata` in `responseFields` in API request to get metad # # @param name [String] Name of the asset. # # @param selected_fields_schema [Hash{Symbol=>Imagekitio::Models::SelectedFieldsSchemaItem}] This field is included in the response only if the Path policy feature is availa # # @param size [Float] Size of the image file in Bytes. # # @param tags [Array<String>, nil] The array of tags associated with the asset. If no tags are set, it will be `nul # # @param thumbnail_url [String] In the case of an image, a small thumbnail URL. # # @param url [String] A publicly accessible URL of the file. # # @param version_info [Imagekitio::Models::VersionInfo] An object containing the file or file version's `id` (versionId) and `name`. # # @param video_codec [String] The video codec used in the video (only for video). # # @param width [Float] Width of the image in pixels (Only for Images) # @see Imagekitio::Models::UploadPreTransformSuccessEvent::Data#extension_status class ExtensionStatus < Imagekitio::Internal::Type::BaseModel # @!attribute ai_auto_description # # @return [Symbol, Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus::AIAutoDescription, nil] optional :ai_auto_description, enum: -> { Imagekitio::UploadPreTransformSuccessEvent::Data::ExtensionStatus::AIAutoDescription }, api_name: :"ai-auto-description" # @!attribute ai_tasks # # @return [Symbol, Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus::AITasks, nil] optional :ai_tasks, enum: -> { Imagekitio::UploadPreTransformSuccessEvent::Data::ExtensionStatus::AITasks }, api_name: :"ai-tasks" # @!attribute aws_auto_tagging # # @return [Symbol, Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus::AwsAutoTagging, nil] optional :aws_auto_tagging, enum: -> { Imagekitio::UploadPreTransformSuccessEvent::Data::ExtensionStatus::AwsAutoTagging }, api_name: :"aws-auto-tagging" # @!attribute google_auto_tagging # # @return [Symbol, Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus::GoogleAutoTagging, nil] optional :google_auto_tagging, enum: -> { Imagekitio::UploadPreTransformSuccessEvent::Data::ExtensionStatus::GoogleAutoTagging }, api_name: :"google-auto-tagging" # @!attribute remove_bg # # @return [Symbol, Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus::RemoveBg, nil] optional :remove_bg, enum: -> { Imagekitio::UploadPreTransformSuccessEvent::Data::ExtensionStatus::RemoveBg }, api_name: :"remove-bg" # @!method initialize(ai_auto_description: nil, ai_tasks: nil, aws_auto_tagging: nil, google_auto_tagging: nil, remove_bg: nil) # Extension names with their processing status at the time of completion of the # request. It could have one of the following status values: # # `success`: The extension has been successfully applied. `failed`: The extension # has failed and will not be retried. `pending`: The extension will finish # processing in some time. On completion, the final status (success / failed) will # be sent to the `webhookUrl` provided. # # If no extension was requested, then this parameter is not returned. # # @param ai_auto_description [Symbol, Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus::AIAutoDescription] # @param ai_tasks [Symbol, Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus::AITasks] # @param aws_auto_tagging [Symbol, Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus::AwsAutoTagging] # @param google_auto_tagging [Symbol, Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus::GoogleAutoTagging] # @param remove_bg [Symbol, Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus::RemoveBg] # @see Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus#ai_auto_description module AIAutoDescription extend Imagekitio::Internal::Type::Enum SUCCESS = :success PENDING = :pending FAILED = :failed # @!method self.values # @return [Array<Symbol>] end # @see Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus#ai_tasks module AITasks extend Imagekitio::Internal::Type::Enum SUCCESS = :success PENDING = :pending FAILED = :failed # @!method self.values # @return [Array<Symbol>] end # @see Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus#aws_auto_tagging module AwsAutoTagging extend Imagekitio::Internal::Type::Enum SUCCESS = :success PENDING = :pending FAILED = :failed # @!method self.values # @return [Array<Symbol>] end # @see Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus#google_auto_tagging module GoogleAutoTagging extend Imagekitio::Internal::Type::Enum SUCCESS = :success PENDING = :pending FAILED = :failed # @!method self.values # @return [Array<Symbol>] end # @see Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus#remove_bg module RemoveBg extend Imagekitio::Internal::Type::Enum SUCCESS = :success PENDING = :pending FAILED = :failed # @!method self.values # @return [Array<Symbol>] end end end |
Instance Attribute Details
#ai_tags ⇒ Array<Imagekitio::Models::AITag>?
An array of tags assigned to the uploaded file by auto tagging.
46 47 48 49 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 46 optional :ai_tags, -> { Imagekitio::Internal::Type::ArrayOf[Imagekitio::AITag] }, api_name: :AITags, nil?: true |
#audio_codec ⇒ String?
The audio codec used in the video (only for video).
55 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 55 optional :audio_codec, String, api_name: :audioCodec |
#bit_rate ⇒ Integer?
The bit rate of the video in kbps (only for video).
61 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 61 optional :bit_rate, Integer, api_name: :bitRate |
#custom_coordinates ⇒ String?
Value of custom coordinates associated with the image in the format ‘x,y,width,height`. If `customCoordinates` are not defined, then it is `null`. Send `customCoordinates` in `responseFields` in API request to get the value of this field.
70 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 70 optional :custom_coordinates, String, api_name: :customCoordinates, nil?: true |
#custom_metadata ⇒ Hash{Symbol=>Object}?
A key-value data associated with the asset. Use ‘responseField` in API request to get `customMetadata` in the upload API response. Before setting any custom metadata on an asset, you have to create the field using custom metadata fields API. Send `customMetadata` in `responseFields` in API request to get the value of this field.
80 81 82 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 80 optional :custom_metadata, Imagekitio::Internal::Type::HashOf[Imagekitio::Internal::Type::Unknown], api_name: :customMetadata |
#description ⇒ String?
Optional text to describe the contents of the file. Can be set by the user or the ai-auto-description extension.
89 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 89 optional :description, String |
#duration ⇒ Integer?
The duration of the video in seconds (only for video).
95 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 95 optional :duration, Integer |
#embedded_metadata ⇒ Hash{Symbol=>Object}?
Consolidated embedded metadata associated with the file. It includes exif, iptc, and xmp data. Send ‘embeddedMetadata` in `responseFields` in API request to get embeddedMetadata in the upload API response.
103 104 105 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 103 optional :embedded_metadata, Imagekitio::Internal::Type::HashOf[Imagekitio::Internal::Type::Unknown], api_name: :embeddedMetadata |
#extension_status ⇒ Imagekitio::Models::UploadPreTransformSuccessEvent::Data::ExtensionStatus?
Extension names with their processing status at the time of completion of the request. It could have one of the following status values:
‘success`: The extension has been successfully applied. `failed`: The extension has failed and will not be retried. `pending`: The extension will finish processing in some time. On completion, the final status (success / failed) will be sent to the `webhookUrl` provided.
If no extension was requested, then this parameter is not returned.
119 120 121 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 119 optional :extension_status, -> { Imagekitio::UploadPreTransformSuccessEvent::Data::ExtensionStatus }, api_name: :extensionStatus |
#file_id ⇒ String?
Unique fileId. Store this fileld in your database, as this will be used to perform update action on this file.
128 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 128 optional :file_id, String, api_name: :fileId |
#file_path ⇒ String?
The relative path of the file in the media library e.g. ‘/marketing-assets/new-banner.jpg`.
135 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 135 optional :file_path, String, api_name: :filePath |
#file_type ⇒ String?
Type of the uploaded file. Possible values are ‘image`, `non-image`.
141 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 141 optional :file_type, String, api_name: :fileType |
#height ⇒ Float?
Height of the image in pixels (Only for images)
147 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 147 optional :height, Float |
#is_private_file ⇒ Boolean?
Is the file marked as private. It can be either ‘true` or `false`. Send `isPrivateFile` in `responseFields` in API request to get the value of this field.
155 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 155 optional :is_private_file, Imagekitio::Internal::Type::Boolean, api_name: :isPrivateFile |
#is_published ⇒ Boolean?
Is the file published or in draft state. It can be either ‘true` or `false`. Send `isPublished` in `responseFields` in API request to get the value of this field.
163 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 163 optional :is_published, Imagekitio::Internal::Type::Boolean, api_name: :isPublished |
#metadata ⇒ Imagekitio::Models::Metadata?
Legacy metadata. Send ‘metadata` in `responseFields` in API request to get metadata in the upload API response.
170 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 170 optional :metadata, -> { Imagekitio::Metadata } |
#name ⇒ String?
Name of the asset.
176 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 176 optional :name, String |
#selected_fields_schema ⇒ Hash{Symbol=>Imagekitio::Models::SelectedFieldsSchemaItem}?
This field is included in the response only if the Path policy feature is available in the plan. It contains schema definitions for the custom metadata fields selected for the specified file path. Field selection can only be done when the Path policy feature is enabled.
Keys are the names of the custom metadata fields; the value object has details about the custom metadata schema.
188 189 190 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 188 optional :selected_fields_schema, -> { Imagekitio::Internal::Type::HashOf[Imagekitio::SelectedFieldsSchemaItem] }, api_name: :selectedFieldsSchema |
#size ⇒ Float?
Size of the image file in Bytes.
196 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 196 optional :size, Float |
#tags ⇒ Array<String>?
The array of tags associated with the asset. If no tags are set, it will be ‘null`. Send `tags` in `responseFields` in API request to get the value of this field.
204 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 204 optional :tags, Imagekitio::Internal::Type::ArrayOf[String], nil?: true |
#thumbnail_url ⇒ String?
In the case of an image, a small thumbnail URL.
210 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 210 optional :thumbnail_url, String, api_name: :thumbnailUrl |
#url ⇒ String?
A publicly accessible URL of the file.
216 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 216 optional :url, String |
#version_info ⇒ Imagekitio::Models::VersionInfo?
An object containing the file or file version’s ‘id` (versionId) and `name`.
222 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 222 optional :version_info, -> { Imagekitio::VersionInfo }, api_name: :versionInfo |
#video_codec ⇒ String?
The video codec used in the video (only for video).
228 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 228 optional :video_codec, String, api_name: :videoCodec |
#width ⇒ Float?
Width of the image in pixels (Only for Images)
234 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 234 optional :width, Float |