Class: Imagekitio::Models::UploadPreTransformSuccessEvent::Data::SelectedFieldsSchema
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Imagekitio::Models::UploadPreTransformSuccessEvent::Data::SelectedFieldsSchema
- Defined in:
- lib/imagekitio/models/upload_pre_transform_success_event.rb
Defined Under Namespace
Modules: DefaultValue, MaxValue, MinValue, SelectOption, Type
Instance Attribute Summary collapse
-
#default_value ⇒ String, ...
The default value for this custom metadata field.
-
#is_value_required ⇒ Boolean?
Specifies if the custom metadata field is required or not.
-
#max_length ⇒ Float?
Maximum length of string.
-
#max_value ⇒ String, ...
Maximum value of the field.
-
#min_length ⇒ Float?
Minimum length of string.
-
#min_value ⇒ String, ...
Minimum value of the field.
-
#read_only ⇒ Boolean?
Indicates whether the custom metadata field is read only.
-
#select_options ⇒ Array<String, Float, Boolean>?
An array of allowed values when field type is
SingleSelectorMultiSelect. -
#select_options_truncated ⇒ Boolean?
Specifies if the selectOptions array is truncated.
-
#type ⇒ Symbol, Imagekitio::Models::UploadPreTransformSuccessEvent::Data::SelectedFieldsSchema::Type
Type of the custom metadata field.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(type:, default_value: nil, is_value_required: nil, max_length: nil, max_value: nil, min_length: nil, min_value: nil, read_only: nil, select_options: nil, select_options_truncated: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SelectedFieldsSchema for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:, default_value: nil, is_value_required: nil, max_length: nil, max_value: nil, min_length: nil, min_value: nil, read_only: nil, select_options: nil, select_options_truncated: nil) ⇒ Object
Some parameter documentations has been truncated, see Imagekitio::Models::UploadPreTransformSuccessEvent::Data::SelectedFieldsSchema for more details.
|
|
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 539
|
Instance Attribute Details
#default_value ⇒ String, ...
The default value for this custom metadata field. The value should match the type of custom metadata field.
464 465 466 467 468 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 464 optional :default_value, union: -> { Imagekitio::UploadPreTransformSuccessEvent::Data::SelectedFieldsSchema::DefaultValue }, api_name: :defaultValue |
#is_value_required ⇒ Boolean?
Specifies if the custom metadata field is required or not.
474 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 474 optional :is_value_required, Imagekitio::Internal::Type::Boolean, api_name: :isValueRequired |
#max_length ⇒ Float?
Maximum length of string. Only set if type is set to Text or Textarea.
480 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 480 optional :max_length, Float, api_name: :maxLength |
#max_value ⇒ String, ...
Maximum value of the field. Only set if field type is Date or Number. For Date type field, the value will be in ISO8601 string format. For Number type field, it will be a numeric value.
488 489 490 491 492 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 488 optional :max_value, union: -> { Imagekitio::UploadPreTransformSuccessEvent::Data::SelectedFieldsSchema::MaxValue }, api_name: :maxValue |
#min_length ⇒ Float?
Minimum length of string. Only set if type is set to Text or Textarea.
498 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 498 optional :min_length, Float, api_name: :minLength |
#min_value ⇒ String, ...
Minimum value of the field. Only set if field type is Date or Number. For Date type field, the value will be in ISO8601 string format. For Number type field, it will be a numeric value.
506 507 508 509 510 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 506 optional :min_value, union: -> { Imagekitio::UploadPreTransformSuccessEvent::Data::SelectedFieldsSchema::MinValue }, api_name: :minValue |
#read_only ⇒ Boolean?
Indicates whether the custom metadata field is read only. A read only field cannot be modified after being set. This field is configurable only via the **Path policy** feature.
518 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 518 optional :read_only, Imagekitio::Internal::Type::Boolean, api_name: :readOnly |
#select_options ⇒ Array<String, Float, Boolean>?
An array of allowed values when field type is SingleSelect or MultiSelect.
524 525 526 527 528 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 524 optional :select_options, -> { Imagekitio::Internal::Type::ArrayOf[union: Imagekitio::UploadPreTransformSuccessEvent::Data::SelectedFieldsSchema::SelectOption] }, api_name: :selectOptions |
#select_options_truncated ⇒ Boolean?
Specifies if the selectOptions array is truncated. It is truncated when number of options are > 100.
535 536 537 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 535 optional :select_options_truncated, Imagekitio::Internal::Type::Boolean, api_name: :selectOptionsTruncated |
#type ⇒ Symbol, Imagekitio::Models::UploadPreTransformSuccessEvent::Data::SelectedFieldsSchema::Type
Type of the custom metadata field.
457 |
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 457 required :type, enum: -> { Imagekitio::UploadPreTransformSuccessEvent::Data::SelectedFieldsSchema::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 578
|
.variants ⇒ Array(String, Float)
|
|
# File 'lib/imagekitio/models/upload_pre_transform_success_event.rb', line 633
|